OC.L10N.register(
    "spreed",
    {
    "a conversation" : "une conversation",
    "(Duration %s)" : "(Durée %s)",
    "You attended a call with {user1}" : "Vous avez participé à un appel avec {user1}",
    "_%n guest_::_%n guests_" : ["%n invité","%n invités","%n invités"],
    "You attended a call with {user1} and {user2}" : "Vous avez participé à un appel avec {user1} et {user2} ",
    "You attended a call with {user1}, {user2} and {user3}" : "Vous avez participé à un appel avec {user1}, {user2} et {user3} ",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Vous avez participé à un appel avec {user1}, {user2}, {user3} et {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Vous avez participé à un appel avec {user1}, {user2}, {user3}, {user4} et {user5}",
    "_%n other_::_%n others_" : ["%n autre","%n autres","%n autres"],
    "{actor} invited you to {call}" : "{actor} vous a invité à {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Vous avez été invité·e à une <strong>conversation</strong> ou avez eu un <strong>appel</strong>",
    "Other activities" : "Autres activités",
    "Talk" : "Talk",
    "Guest" : "Invité",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Bienvenue sur Nextcloud Talk !\nDans cette conversation, vous serez informé des nouvelles fonctionnalités disponibles sur Nextcloud Talk.",
    "## New in Talk %s" : "## Nouveau sur Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge et Safari peuvent désormais être utilisés pour participer aux appels audio et vidéo",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Les conversations un-à-un sont désormais persistantes et ne peuvent plus être transformées en conversations de groupe par accident. De plus, lorsque l'un des participants quitte la conversation, celle-ci n'est plus automatiquement supprimée. Ce n'est que si les deux participants quittent la conversation que celle-ci est supprimée du serveur.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "-  Vous pouvez notifier tous les participants en écrivant \"@all\" dans la discussion",
    "- With the \"arrow-up\" key you can repost your last message" : "- Avec la touche \"flèche du haut\" vous pouvez renvoyer votre dernier message",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk peut maintenant utiliser des commandes, envoyez \"/help\" comme un message dans le chat pour vérifier si l'administrateur en a configuré",
    "- With projects you can create quick links between conversations, files and other items" : "- Avec les projets vous pouvez créer des liens rapides entre des conversations, des fichiers et d'autres éléments",
    "- You can now mention guests in the chat" : "- Désormais vous pouvez mentionner les invités dans la discussion",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Les conversations peuvent désormais avoir une salle d'attente. Cela permet aux modérateurs de rejoindre la conversation et l'appel afin de préparer la réunion pendant que les invités attendent",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Vous pouvez maintenant répondre directement aux messages, ce qui permet aux autres utilisateurs de mieux comprendre le contexte de votre message",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- La recherche de conversations et de participants permet désormais de filtrer vos conversations existantes, ce qui facilite considérablement la recherche de conversations antérieures",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Vous pouvez désormais ajouter des groupes d'utilisateurs aux conversations lorsque l'application Cercles est installée",
    "- Check out the new grid and call view" : "- Découvrez la nouvelle vue en grille des appels",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Vous pouvez maintenant téléverser et glisser-déposer des fichiers directement depuis votre appareil vers la discussion.",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "Les fichiers partagés sont maintenant ouverts directement à l'intérieur de la conversation avec les applications de visionnage",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Vous pouvez maintenant rechercher dans les discussions et les messages depuis la recherche unifiée de la barre supérieure",
    "- Spice up your messages with emojis from the emoji picker" : "- Mettez du piment dans vos messages avec les émojis du sélecteur d'émojis",
    "- You can now change your camera and microphone while being in a call" : "- Vous pouvez maintenant modifier votre microphone et votre caméra pendant l'appel",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Donnez à vos conversations un contexte avec une description et ouvrez-les pour que les utilisateurs connectés puissent les trouver et s'y joindre.",
    "- See a read status and send failed messages again" : "- Voir un statut de lecture et renvoyer les messages échoués",
    "- Raise your hand in a call with the R key" : "- Lever la main lors d'un appel avec la touche R",
    "- Join the same conversation and call from multiple devices" : "- Participez à la même conversation et appel depuis plusieurs appareils",
    "- Send voice messages, share your location or contact details" : "- Envoyez des messages vocaux, partagez votre emplacement ou vos coordonnées",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Ajoutez des groupes à une conversation et les nouveaux membres du groupe seront automatiquement ajoutés en tant que participants",
    "- A preview of your audio and video is shown before joining a call" : "- Une prévisualisation de vos flux audio et vidéo est montrée avant de rejoindre un appel",
    "- You can now blur your background in the newly designed call view" : "- Vous pouvez maintenant flouter l'arrière-plan dans la nouvelle disposition de la fenêtre d'appel",
    "- Moderators can now assign general and individual permissions to participants" : "- Les modérateurs peuvent maintenant donner des permissions générales et individuelles aux participants",
    "- You can now react to chat messages" : "- Vous pouvez maintenant réagir aux messages instantanés",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Dans le panneau latéral, vous pouvez désormais trouver une vue globale des derniers éléments partagés",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Utiliser un sondage pour connaître l'opinion des autres ou définir une date",
    "- Configure an expiration time for chat messages" : "- Configurer une durée d'expiration pour les messages",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Lancez les appels sans notifier les autres dans les grandes conversations. Vous pouvez envoyer une notification d'appel individuel une fois que l'appel a commencé.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Envoi des messages sans notifier les destinataires si ce n'est pas urgent",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Les émojis peuvent maintenant être autocomplétés en tapant un « : »",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Liez divers éléments grâce au sélecteur intelligent en tapant un « / »",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Les modérateurs peuvent maintenant créer des salles de sous-groupe (nécessite un serveur haute performance)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Les appels peuvent maintenant être enregistrés (nécessite un serveur haute performance)",
    "- Conversations can now have an avatar or emoji as icon" : "- Les conversations peuvent maintenant avoir comme icône un avatar ou un emoji",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- des fonds d'écran virtuels sont maintenant disponibles en plus du fond flouté pour les appels vidéos",
    "- Reactions are now available during calls" : "- Les réactions sont maintenant possible pendant les appels",
    "- Typing indicators show which users are currently typing a message" : "- Des indicateurs montrent quels utilisateurs sont actuellement en train d'écrire des messages",
    "- Groups can now be mentioned in chats" : "- Les groupes peuvent maintenant être mentionnés dans les conversations",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Les enregistrements d'appel sont automatiquement retranscrits si une application de transcription est configurée",
    "- Chat messages can be translated if a translation provider app is registered" : "- Les messages peuvent être traduits automatiquement si une application de traduction est configurée",
    "- **Markdown** can now be used in _chat_ messages" : "- La syntaxe **Markdown** peut maintenant être utilisée dans la messagerie instantanée",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Les Webhooks sont maintenant disponibles pour créer des robots conversationnels. Voir la documentation pour plus d'informations : https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Définir un rappel sur un message pour être notifié à nouveau plus tard",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Utiliser la conversation \"Note à soi-même\" pour prendre des notes et partager des infos entre vos appareils",
    "- Captions allow to send a message with a file at the same time" : "- Légendes permet d'envoyer un message avec un fichier en même temps",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- La vidéo de l’intervenant est maintenant visible quand le partage d’écran est activé et les réactions sont animées",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Les messages peuvent maintenant être modifiés par les auteurs connectés et les modérateurs pendant 6 heures",
    "- Unsent message drafts are now saved in your browser" : "- Les messages non envoyés sont maintenant sauvegardés dans votre navigateur",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Le chat textuel peut désormais être effectué de manière fédérée avec d'autres serveurs Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Les modérateurs peuvent maintenant bannir les comptes et les invités pour éviter qu'ils ne rejoignent à nouveau une conversation",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Les prochaines réunions fixées dans les évènements liés du calendrier et les remplaçants pendant les absences sont maintenant visibles dans les conversations",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Les appels peuvent désormais être effectués de manière fédérée avec d'autres serveurs Talk (nécessite le backend hautes performances)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Introduction du client Nextcloud Talk pour Windows, macOS et Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Résume les enregistrements d'appel et les messages non lus dans les discussions avec l'Assistant Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Réunions améliorées avec la reconnaissance des invités via leur adresse e-mail, l'import de liste de participants, des brouillons pour les sondages et le téléchargement de la liste des participants à un appel.",
    "- Archive conversations to stay focused" : "- Archivage des conversations pour rester concentré",
    "- Schedule a meeting into your calendar from within a conversation" : "- Planifier une réunion dans votre calendrier depuis une conversation",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Rechercher des messages de la conversation actuelle directement depuis le panneau latéral de droite",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Voir plus de conversations d'un seul coup d'oeil avec la nouvelle liste compacte (à activer dans les paramètres de Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Les conversations liées à des réunions ont maintenant leur titre et description synchronisée avec le calendrier et son masquées avec un filtre de recherche jusqu'à ce que leur date de début approche.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Marquez les conversations comme sensibles dans les paramètres de notification, pour cacher les contenus des messages de la liste des conversations et des notifications",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Pour recevoir des notifications push en mode \"Ne pas déranger\", marquer les conversations comme importantes",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Ajouter des participants à une conversation privée pour créer un nouvel appel de groupe à la volée",
    "- Use threads to keep your chat and discussions organized" : "- Utilisez les fils de discussion pour organiser vos conversations et vos discussions",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Les transcriptions en direct sont désormais disponibles pendant l'appel (nécessite l'application ExApp de transcription en direct et le backend haute performance)",
    "- Moderators can now pin messages so they are kept at the top" : "- Les modérateurs peuvent désormais épingler des messages afin qu'ils restent en haut de la page. ",
    "- Schedule a message to send it at a later time" : "- Programmer un message pour l'envoyer plus tard",
    "_All %n participant_::_All %n participants_" : ["Le participant","Les %n participants","Les %n participants"],
    "Talk updates ✅" : "Mises à jour de Talk ✅",
    "Reaction deleted by author" : "Réaction supprimée par son auteur",
    "{actor} created the conversation" : "{actor} a créé la conversation",
    "You created the conversation" : "Vous avez créé la conversation",
    "System created the conversation" : "Le système a créé la conversation",
    "An administrator created the conversation" : "Un administrateur a créé la conversation",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} a renommé la conversation de \"%1$s\" à \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Vous avez renommé la conversation de \"%1$s\" à \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un administrateur a renommé la conversation de \"%1$s\" à \"%2$s\"",
    "{actor} set the description" : "{actor} a renseigné la description",
    "You set the description" : "Vous avez renseigné la description",
    "An administrator set the description" : "Un administrateur a renseigné la description",
    "{actor} removed the description" : "{actor} a supprimé la description",
    "You removed the description" : "Vous avez supprimé la description",
    "An administrator removed the description" : "Un administrateur a supprimé la description",
    "You started a silent call" : "Vous avez lancé un appel silencieux",
    "Outgoing silent call" : "Appel silencieux sortant",
    "{actor} started a silent call" : "{actor} a lancé un appel silencieux",
    "Incoming silent call" : "Appel silencieux entrant",
    "You started a call" : "Vous avez lancé un appel",
    "Outgoing call" : "Appel sortant",
    "{actor} started a call" : "{actor} a lancé un appel",
    "Incoming call" : "Appel entrant",
    "{actor} joined the call" : "{actor} a rejoint l'appel",
    "You joined the call" : "Vous avez rejoint l'appel",
    "{actor} left the call" : "{actor} a quitté l'appel",
    "You left the call" : "Vous avez quitté l'appel",
    "{actor} unlocked the conversation" : "{actor} a déverrouillé la conversation",
    "You unlocked the conversation" : "Vous avez déverrouillé la conversation",
    "An administrator unlocked the conversation" : "Un administrateur a déverrouillé la conversation",
    "{actor} locked the conversation" : "{actor} a verrouillé la conversation",
    "You locked the conversation" : "Vous avez verrouillé la conversation",
    "An administrator locked the conversation" : "Un administrateur a verrouillé la conversation",
    "{actor} limited the conversation to the current participants" : "{actor} a restreint la conversation aux participants actuels",
    "You limited the conversation to the current participants" : "Vous avez restreint la conversation aux participants actuels",
    "An administrator limited the conversation to the current participants" : "Un administrateur a restreint la conversation aux participants actuels",
    "{actor} opened the conversation to registered users" : "{actor} a ouvert la conversation aux utilisateurs enregistrés",
    "You opened the conversation to registered users" : "Vous avez ouvert la conversation aux utilisateurs enregistrés",
    "An administrator opened the conversation to registered users" : "Un administrateur a ouvert la conversation aux utilisateurs enregistrés",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} a ouvert la conversation aux utilisateurs enregistrés et aux utilisateurs créés avec l'application Invités.",
    "You opened the conversation to registered users and users created with the Guests app" : "Vous avez ouvert la conversation aux utilisateurs enregistrés et aux utilisateurs créés avec l'application Invités",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Un administrateur a ouvert la conversation aux utilisateurs enregistrés et aux utilisateurs créés avec l'application Invités.",
    "The conversation is now open to everyone" : "La conversation est maintenant ouverte à tout le monde",
    "{actor} opened the conversation to everyone" : "{actor} a ouvert la conversation à tout le monde",
    "You opened the conversation to everyone" : "Vous avez ouvert la conversation à tout le monde.",
    "{actor} restricted the conversation to moderators" : "{actor} a restreint la conversation aux modérateurs",
    "You restricted the conversation to moderators" : "Vous avez restreint la conversation aux modérateurs",
    "{actor} started breakout rooms" : "{actor} a démarré les salles de sous-groupes",
    "You started breakout rooms" : "Vous avez démarré les salles de sous-groupes",
    "{actor} stopped breakout rooms" : "{actor} a stoppé les salles de sous-groupes",
    "You stopped breakout rooms" : "Vous avez mis fin aux salles de sous-groupes",
    "{actor} allowed guests" : "{actor} a autorisé les invités",
    "You allowed guests" : "Vous avez autorisé les invités",
    "An administrator allowed guests" : "Un administrateur a autorisé les invités",
    "{actor} disallowed guests" : "{actor} a désactivé les invités",
    "You disallowed guests" : "Vous avez désactivé les invités",
    "An administrator disallowed guests" : "Un administrateur a désactivé les invités",
    "{actor} set a password" : "{actor} a défini un mot de passe",
    "You set a password" : "Vous avez défini un mot de passe",
    "An administrator set a password" : "Un administrateur a défini un mot de passe",
    "{actor} removed the password" : "{actor} a supprimé le mot de passe",
    "You removed the password" : "Vous avez supprimé le mot de passe",
    "An administrator removed the password" : "Un administrateur a supprimé le mot de passe",
    "{actor} added {user}" : "{actor} a ajouté {user}",
    "You joined the conversation" : "Vous avez rejoint la conversation",
    "{actor} joined the conversation" : "{actor} a rejoint la conversation",
    "You added {user}" : "Vous avez ajouté {user}",
    "{actor} added you" : "{actor} vous a ajouté",
    "An administrator added you" : "Un administrateur vous a ajouté",
    "An administrator added {user}" : "Un administrateur a ajouté {user}",
    "You left the conversation" : "Vous avez quitté la conversation",
    "{actor} left the conversation" : "{actor} a quitté la discussion",
    "{actor} removed {user}" : "{actor} a retiré {user}",
    "You removed {user}" : "Vous avez retiré {user}",
    "{actor} removed you" : "{actor} vous a retiré",
    "An administrator removed you" : "Un administrateur vous a retiré",
    "An administrator removed {user}" : "Un administrateur a retiré {user}",
    "{actor} invited {federated_user}" : "{actor} a invité {federated_user}",
    "You invited {federated_user}" : "Vous avez invité {federated_user}",
    "You accepted the invitation" : "Vous avez accepté l'invitation",
    "{actor} invited you" : "{actor} vous a invité",
    "An administrator invited you" : "Un administrateur vous a invité",
    "An administrator invited {federated_user}" : "Un administrateur a invité {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} a accepté l'invitation",
    "{actor} removed {federated_user}" : "{actor} a retiré {federated_user}",
    "You removed {federated_user}" : "Vous avez retiré {federated_user}",
    "You declined the invitation" : "Vous avez décliné l'invitation",
    "An administrator removed {federated_user}" : "Un administrateur a retiré {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} a refusé l'invitation",
    "{actor} added group {group}" : "{actor} a ajouté le groupe {group}",
    "You added group {group}" : "Vous avez ajouté le groupe {group}",
    "An administrator added group {group}" : "Un administrateur a ajouté le groupe {group}",
    "{actor} removed group {group}" : "{actor} a supprimé le groupe {group}",
    "You removed group {group}" : "Vous avez supprimé le groupe {group}",
    "An administrator removed group {group}" : "Un administrateur a supprimé le groupe {group}",
    "{actor} added team {circle}" : "{actor} a ajouté l’équipe {circle}",
    "You added team {circle}" : "Vous avez ajouté l’équipe {circle}",
    "An administrator added team {circle}" : "Un administrateur a ajouté l’équipe {circle}",
    "{actor} removed team {circle}" : "{actor} a supprimé l’équipe {circle}",
    "You removed team {circle}" : "Vous avez supprimé l’équipe {circle}",
    "An administrator removed team {circle}" : "Un administrateur a supprimé l’équipe {circle}",
    "{actor} added {phone}" : "{actor} a ajouté {phone}",
    "You added {phone}" : "Vous avez ajouté {phone}",
    "An administrator added {phone}" : "Un administrateur a ajouté {phone}",
    "{actor} removed {phone}" : "{actor} a supprimé {phone}",
    "You removed {phone}" : "Vous avez supprimé {phone}",
    "An administrator removed {phone}" : "Un administrateur a supprimé {phone}",
    "{actor} promoted {user} to moderator" : "{actor} a promu {user} modérateur",
    "You promoted {user} to moderator" : "Vous avez promu {user} modérateur",
    "{actor} promoted you to moderator" : "{actor} vous a promu modérateur",
    "An administrator promoted you to moderator" : "Un administrateur vous a promu modérateur",
    "An administrator promoted {user} to moderator" : "Un administrateur a promu {user} modérateur",
    "{actor} demoted {user} from moderator" : "{actor} a retiré à {user} le rôle de modérateur",
    "You demoted {user} from moderator" : "Vous avez retiré à {user} son rôle de modérateur",
    "{actor} demoted you from moderator" : "{actor} vous a retiré le rôle de modérateur",
    "An administrator demoted you from moderator" : "Un administrateur vous a retiré le rôle de modérateur",
    "An administrator demoted {user} from moderator" : "Un administrateur a retiré à {user} le rôle de modérateur",
    "{actor} shared a file which is no longer available" : "{actor} a partagé un fichier qui n'est plus disponible",
    "You shared a file which is no longer available" : "Vous avez partagé un fichier qui n'est plus disponible",
    "File shares are currently not supported in federated conversations" : "Le partage de fichiers n'est actuellement pas supporté dans les conversations fédérées",
    "The shared location is malformed" : "L'emplacement partagé est mal formaté",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} a configuré Matterbridge pour synchroniser la conversation avec d'autres messageries instantanées",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Vous avez configuré Matterbridge pour synchroniser la conversation avec d'autres messageries instantanées",
    "{actor} created thread {title}" : "{actor} a créé le fil de discussion {title}",
    "You created thread {title}" : "Vous avez créé le fil de discussion {title}",
    "{actor} renamed thread {title}" : "{actor} a renommé le fil de discussion {title}",
    "You renamed thread {title}" : "Vous avez renommé le fil de discussion {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} a mis à jour la configuration de Matterbridge",
    "You updated the Matterbridge configuration" : "Vous avez modifié la configuration de Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} a supprimé la configuration de Matterbridge",
    "You removed the Matterbridge configuration" : "Vous avez supprimé la configuration de Matterbridge",
    "{actor} started Matterbridge" : "{actor} a démarré Matterbridge",
    "You started Matterbridge" : "Vous avez démarré Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} a arrêté Matterbridge",
    "You stopped Matterbridge" : "Vous avez arrêté Matterbridge",
    "{actor} deleted a message" : "{actor} a supprimé un message",
    "You deleted a message" : "Vous avez supprimé un message",
    "{actor} edited a message" : "{actor} a modifié un message",
    "You edited a message" : "Vous avez modifié un message",
    "{actor} pinned a message" : "{actor} a épinglé un message",
    "You pinned a message" : "Vous avez épinglé un message",
    "{actor} unpinned a message" : "{actor} a désépinglé un message",
    "Message was automatically unpinned" : "Le message a été désépinglé automatiquement",
    "You unpinned a message" : "Vous avez désépinglé un message",
    "{actor} deleted a reaction" : "{actor} a supprimé une réaction",
    "You deleted a reaction" : "Vous avez supprimé une réaction",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Vous avez défini l'expiration des messages à %n semaine","Vous avez défini l'expiration des messages à %n semaines","Vous avez défini l'expiration des messages à %n semaines"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Vous avez défini l'expiration des messages à %n jour","Vous avez défini l'expiration des messages à %n jours","Vous avez défini l'expiration des messages à %n jours"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Vous avez défini l'expiration des messages à %n heure","Vous avez défini l'expiration des messages à %n heures","Vous avez défini l'expiration des messages à %n heures"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Vous avez défini l'expiration des messages à %n minute","Vous avez défini l'expiration des messages à %n minutes","Vous avez défini l'expiration des messages à %n minutes"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} a défini l'expiration des messages à  %n semaine","{actor} a défini l'expiration des messages à  %n semaines","{actor} a défini l'expiration des messages à %n semaines"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} a défini l'expiration des messages à  %n jour","{actor} a défini l'expiration des messages à  %n jours","{actor} a défini l'expiration des messages à  %n jours"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} a défini l'expiration des messages à  %n heure","{actor} a défini l'expiration des messages à  %n heures","{actor} a défini l'expiration des  messages à  %n heures"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} a défini l'expiration des messages à %n minute","{actor} a défini l'expiration des messages à %n minutes","{actor} a défini l'expiration des messages à  %n minutes"],
    "{actor} disabled message expiration" : "{actor} a désactivé l'expiration des messages",
    "You disabled message expiration" : "Vous avez désactivé l'expiration des messages",
    "{actor} cleared the history of the conversation" : "{actor} a effacé l'historique de la conversation",
    "You cleared the history of the conversation" : "Vous avez effacé l'historique de la conversation",
    "{actor} set the conversation picture" : "{actor} a défini l'image de la conversation",
    "You set the conversation picture" : "Vous avez sélectionné une image pour la conversation",
    "{actor} removed the conversation picture" : "{actor} a supprimé l'image de la conversation",
    "You removed the conversation picture" : "Vous avez supprimé l'image de la conversation",
    "{actor} ended the poll {poll}" : "{actor} a mis fin au sondage {poll}",
    "You ended the poll {poll}" : "Vous avez mis fin au sondage {poll}",
    "{actor} started the video recording" : "{actor} a lancé l'enregistrement vidéo",
    "You started the video recording" : "Vous avez lancé l'enregistrement vidéo",
    "{actor} stopped the video recording" : "{actor} a stoppé l'enregistrement vidéo",
    "You stopped the video recording" : "Vous avez stoppé l'enregistrement vidéo",
    "{actor} started the audio recording" : "{actor} a lancé l'enregistrement audio",
    "You started the audio recording" : "Vous avez lancé l'enregistrement audio",
    "{actor} stopped the audio recording" : "{actor} a stoppé l'enregistrement audio",
    "You stopped the audio recording" : "Vous avez stoppé l'enregistrement audio",
    "The recording failed" : "L'enregistrement a échoué",
    "Someone voted on the poll {poll}" : "Quelqu'un a participé au sondage {poll}",
    "Message deleted by author" : "Message supprimé par l'auteur",
    "Message deleted by {actor}" : "Message supprimé par {actor}",
    "Message deleted by you" : "Message supprimé par vous",
    "Deleted user" : "Utilisateur supprimé",
    "Unknown number" : "Numéro inconnu",
    "Administration" : "Administration",
    "System" : "Système",
    "%s (guest)" : "%s (invité)",
    "Missed call" : "Appel manqué",
    "Unanswered call" : "Appel sans réponse",
    "Call ended (Duration {duration})" : "L'appel a pris fin (Durée {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "L'appel a pris fin, car il a atteint la durée maximale (Durée {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} a mis fin à l'appel (Durée {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["L'appel avec %n invité a pris fin, car il a atteint la durée maximale (Durée {duration})","L'appel avec %n invités a pris fin, car il a atteint la durée maximale (Durée {duration})","L'appel avec %n invités a pris fin, car il a atteint la durée maximale (Durée {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["L'appel avec %n invité a pris fin (Durée {duration})","L'appel avec %n invités a pris fin (Durée {duration})","L'appel avec %n invités a pris fin (Durée {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} a terminé l'appel avec %n invité (Durée {duration})","{actor} a terminé l'appel avec %n invités (Durée {duration})","{actor} a terminé l'appel avec %n invités (Durée {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "L'appel avec {user1} a pris fin, car il a atteint la durée maximale (Durée {duration})",
    "Call with {user1} ended (Duration {duration})" : "Fin de l'appel avec {user1} (Durée {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} a terminé l'appel avec {user1} (Durée {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "L'appel avec {user1} et {user2} a pris fin, car il a atteint la durée maximale (Durée {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "L'appel avec {user1} et {user2} a pris fin (Durée {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} a mis fin à l'appel avec {user1} et {user2} (Durée {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "L'appel avec {user1}, {user2} et {user3} a pris fin, car il a atteint la durée maximale (Durée {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "L'appel avec {user1}, {user2} et {user3} a pris fin (Durée {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} a mis fin à l'appel avec {user1}, {user2} et {user3} (Durée {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "L'appel avec {user1}, {user2}, {user3} et {user4} a pris fin, car il a atteint la durée maximale (Durée {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "L'appel avec {user1}, {user2}, {user3} et {user4} a pris fin (Durée {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} a mis fin à l'appel avec {user1}, {user2}, {user3} et {user4} (Durée {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "L'appel avec {user1}, {user2}, {user3}, {user4} et {user5} a pris fin, car il a atteint la durée maximale (Durée {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "L'appel avec {user1}, {user2}, {user3}, {user4} et {user5} a pris fin (Durée {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} a mis fin à l'appel avec {user1}, {user2}, {user3}, {user4} et {user5} (Durée {duration})",
    "Message of {user} in {conversation}" : "Message de {user} dans {conversation}",
    "Message of {user}" : "Message de {user}",
    "Message of a deleted user in {conversation}" : "Message d'un utilisateur supprimé dans {conversation}",
    "Talk conversations" : "Conversations orales",
    "Talk to %s" : "Discuter avec %s",
    "An error occurred. Please contact your administrator." : "Une erreur est survenue. Merci de contacter votre administrateur.",
    "Storage quota exceeded" : "Quota de stockage dépassé",
    "File not found" : "Fichier non trouvé",
    "File is not shared, or shared but not with the user" : "Le fichier n'est pas partagé, ou partagé mais pas avec cet utilisateur",
    "No account available to delete." : "Aucun compte disponible à supprimer",
    "Poll" : "Sondage",
    "Password needs to be set" : "Le mot de passe doit être défini",
    "Uploading the file failed" : "Le téléversement du fichier a échoué",
    "No image file provided" : "Aucun fichier image fourni",
    "File is too big" : "Le fichier est trop gros",
    "Invalid file provided" : "Fichier invalide fourni",
    "Invalid image" : "Image invalide",
    "Unknown filetype" : "Type de fichier inconnu",
    "Talk mentions" : "Mentions sur Talk",
    "More conversations" : "Plus de conversations",
    "Say hi to your friends and colleagues!" : "Dites bonjour à vos amis et collègues !",
    "No unread mentions" : "Aucune mention non lue",
    "Call in progress" : "Appel en cours",
    "You were mentioned" : "Vous avez été mentionné·e",
    "Write to conversation" : "Écrire dans la conversation",
    "Writes event information into a conversation of your choice" : "Écrit l'évènement dans une conversation de votre choix",
    "Missing email field in header line" : "Le champ e-mail est absent dans la ligne d'entête",
    "Following lines are invalid: %s" : "Les lignes suivantes sont invalides : %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s vous a invité à la conversation \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Vous avez été invité·e à la conversation \"%s\".",
    "Conversation invitation" : "Invitation à une discussion",
    "Scheduled time" : "Horaire programmé",
    "Description" : "Description",
    "You can also dial-in via phone with the following details" : "Vous pouvez aussi appeler au téléphone en utilisant les informations suivantes",
    "Dial-in information" : "Informations d'appel",
    "Meeting ID" : "ID de réunion",
    "Your PIN" : "Votre PIN",
    "Click the button below to join the lobby now." : "Cliquez sur le bouton ci-dessous pour rejoindre la salle d'attente dès maintenant.",
    "Click the link below to join the lobby now." : "Cliquez sur le lien ci-dessous pour rejoindre la salle d'attente dès maintenant.",
    "Join lobby for \"%s\"" : "Rejoignez le hall \"%s\"",
    "Click the button below to join the conversation now." : "Cliquez le bouton ci-dessous pour rejoindre la conversation maintenant.",
    "Click the link below to join the conversation now." : "Cliquez sur le lien ci-dessous pour rejoindre la conversation maintenant.",
    "Join \"%s\"" : "Rejoindre \"%s\"",
    "Meeting" : "Réunion",
    "Password request: %s" : "Demande de mot de passe : %s",
    "Private conversation" : "Conversation privée",
    "Deleted user (%s)" : "Utilisateur supprimé (%s)",
    "Failed to upload call recording" : "Le téléversement de l'enregistrement de l'appel a échoué",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Le serveur d'enregistrement n'a pas réussi à téléverser l'enregistrement de l'appel {call}. Veuillez contacter l'administrateur.",
    "Share to chat" : "Partager pour discuter",
    "Dismiss notification" : "Ignorer la notification",
    "Call recording now available" : "Enregistrement de l'appel maintenant disponible",
    "The recording for the call in {call} was uploaded to {file}." : "L'enregistrement de l'appel dans {call} a été téléversé vers {file}.",
    "Transcript now available" : "Transcription maintenant disponible",
    "The transcript for the call in {call} was uploaded to {file}." : "La transcription de l'appel {call} a été téléversé vers {file}.",
    "Failed to transcript call recording" : "Impossible de transcrire l'enregistrement d'appel",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Le serveur n'est pas parvenu à transcrire l'enregistrement vers {file} pour l'appel {call}. Merci de contacter l'administrateur.",
    "Call summary now available" : "Le résumé de l'appel est maintenant disponible",
    "The summary for the call in {call} was uploaded to {file}." : "Le résumé de l'appel dans la conversation {call} a été téléversé dans {file}.",
    "Failed to summarize call recording" : "Échec du résumé de l'enregistrement de l'appel",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Le serveur n'a pas réussi à résumer l'enregistrement dans {file} pour l'appel dans la conversation {call}. Merci de contacter l'administrateur.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} vous a invité à rejoindre {roomName} sur {remoteServer}",
    "Accept" : "Accepter",
    "Decline" : "Décliner",
    "{user1} invited you to a federated conversation" : "{user1} vous a invité dans une conversation fédérée",
    "Someone reacted" : "Quelqu'un a réagi",
    "New message" : "Nouveau message",
    "Reminder" : "Rappel",
    "Someone mentioned you" : "Quelqu'un vous a mentionné",
    "Notification" : "Notification",
    "Someone reacted in a private conversation" : "Quelqu'un a réagi dans une conversation privée",
    "You received a message in a private conversation" : "Vous avez reçu un message dans une conversation privée",
    "Reminder in a private conversation" : "Rappel dans une conversation privée",
    "Someone mentioned you in a private conversation" : "Quelqu'un vous a mentionné dans une conversation privée",
    "Notification in a private conversation" : "Notification dans une conversation privée",
    "Reminder: You in {call}" : "Rappel : vous dans {call}",
    "Reminder: {user} in {call}" : "Rappel : {user} dans {call}",
    "Reminder: Deleted user in {call}" : "Rappel : utilisateur supprimé dans {call}",
    "Reminder: {guest} (guest) in {call}" : "Rappel : {guest} (invité) dans {call}",
    "Reminder: Guest in {call}" : "Rappel : invité dans {call}",
    "{user} reacted with {reaction}" : "{user} a réagi avec {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} a réagi avec {reaction} dans {call}",
    "Deleted user reacted with {reaction} in {call}" : "Un utilisateur supprimé a réagi avec {reaction} dans {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (invité) a réagi avec {reaction} dans {call}",
    "Guest reacted with {reaction} in {call}" : "Un invité a réagi avec {reaction} dans {call}",
    "{user} in {call}" : "{user} dans {call}",
    "Deleted user in {call}" : "Utilisateur supprimé dans {call}",
    "{guest} (guest) in {call}" : "{guest} (invité) dans {call}",
    "Guest in {call}" : "Invité dans {call}",
    "{user} sent you a private message" : "{user} vous a envoyé un message privé",
    "{user} sent a message in conversation {call}" : "{user} a envoyé un message dans la conversation {call}",
    "A deleted user sent a message in conversation {call}" : "Un utilisateur (maintenant supprimé) a envoyé un message dans la conversation {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) a publié un message dans la conversation {call}",
    "A guest sent a message in conversation {call}" : "Un invité a envoyé un message dans la conversation {call}",
    "{user} replied to your private message" : "{user} a répondu à votre message privé",
    "{user} replied to your message in conversation {call}" : "{user} a répondu à votre message dans la conversation {call}",
    "A deleted user replied to your message in conversation {call}" : "Un utilisateur supprimé a répondu à votre message dans la conversation {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (guest) a répondu à votre message dans la conversation {call}",
    "A guest replied to your message in conversation {call}" : "Un invité a répondu à votre message dans la conversation {call}",
    "Reminder: You in private conversation {call}" : "Rappel : vous dans la conversation privée {call}",
    "Reminder: A deleted user in private conversation {call}" : "Rappel : un utilisateur supprimé dans la conversation privée {call}",
    "Reminder: {user} in private conversation" : "Rappel : {user} dans une conversation privée",
    "Reminder: You in conversation {call}" : "Rappel : vous dans la conversation {call}",
    "Reminder: {user} in conversation {call}" : "Rappel : {user} dans la conversation {call}",
    "Reminder: A deleted user in conversation {call}" : "Rappel : un utilisateur supprimé dans la conversation {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Rappel : {guest} (invité) dans la conversation {call}",
    "Reminder: A guest in conversation {call}" : "Rappel : un invité dans la conversation {call}",
    "{user} reacted with {reaction} to your private message" : "{user} a réagi avec {reaction} à votre message privé",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} a réagi avec {reaction} à votre message dans la conversation {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Un utilisateur supprimé a réagi avec {reaction} à votre message dans la conversation {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (invité) a réagi avec {reaction} à votre message dans la conversation {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Un invité a réagi avec {reaction} à votre message dans la conversation {call}",
    "{user} mentioned you in a private conversation" : "{user} vous a mentionné dans une conversation privée",
    "{user} mentioned group {group} in conversation {call}" : "{user} a mentionné le groupe {group} dans la conversation {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} a mentionné l'équipe {team} dans la conversation {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} a mentionné tout le monde dans la conversation {call}",
    "{user} mentioned you in conversation {call}" : "{user} vous a mentionné dans la conversation {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Un utilisateur supprimé a mentionné le groupe {group} dans la conversation {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Un utilisateur supprimé a mentionné l'équipe {team} dans la conversation {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Un utilisateur supprimé a mentionné tout le monde dans la conversation {call}",
    "A deleted user mentioned you in conversation {call}" : "Un utilisateur (maintenant supprimé) vous a mentionné dans la conversation {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (invité) a mentionné le groupe {group} dans la conversation {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (invité) a mentionné l'équipe {team} dans la conversation {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (invité) a mentionné tout le monde dans la conversation {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (guest) vous a mentionné dans la conversation {call}",
    "A guest mentioned group {group} in conversation {call}" : "Un invité a mentionné le groupe {group} dans la conversation {call}",
    "A guest mentioned team {team} in conversation {call}" : "Un invité a mentionné l'équipe {team} dans la conversation {call}",
    "A guest mentioned everyone in conversation {call}" : "Un invité a mentionné tout le monde dans la conversation {call}",
    "A guest mentioned you in conversation {call}" : "Un invité vous a mentionné dans la conversation {call}",
    "View message" : "Voir message",
    "Dismiss reminder" : "Faire disparaître le rappel",
    "View chat" : "Afficher la discussion",
    "{user} invited you to a group conversation: {call}" : "{user} vous a invité dans une conversation de groupe : {call}",
    "Join call" : "Rejoindre l'appel",
    "Answer call" : "Répondre à l'appel",
    "{user} would like to talk with you" : "{user} souhaite vous parler",
    "Call back" : "Rappeler",
    "You missed a call from {user}" : "Vous avez manqué l'appel de {user}",
    "Accept call" : "Accepter l'appel",
    "Incoming phone call from {call}" : "Appel téléphonique de {call}",
    "You missed a phone call from {call}" : "Vous avez raté un appel téléphonique de {call}",
    "A group call has started in {call}" : "Un appel de groupe a été lancé dans {call}",
    "You missed a group call in {call}" : "Vous avez manqué l'appel de groupe {call}",
    "{email} is requesting the password to access {file}" : "{email} demande le mot de passe pour accéder au fichier {file}",
    "{email} tried to request the password to access {file}" : "{email} a essayé d'obtenir le mot de passe pour accéder au fichier {file}",
    "Someone is requesting the password to access {file}" : "Quelqu'un demande le mot de passe pour accéder au fichier {file}",
    "Someone tried to request the password to access {file}" : "Quelqu'un a essayé d'obtenir le mot de passe pour accéder au fichier {file}",
    "Open settings" : "Ouvrir les paramètres",
    "Hosted signaling server added" : "Le signaling server hébergé a été ajouté ",
    "The hosted signaling server is now configured and will be used." : "Le serveur de signalement hébergé est maintenant configuré et sera utilisé.",
    "Hosted signaling server removed" : "Le signaling server hébergé a été supprimé",
    "The hosted signaling server was removed and will not be used anymore." : "Le serveur de signalement hébergé a été supprimé et ne sera plus utilisé.",
    "Hosted signaling server changed" : "Le signaling server hébergé a changé",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Le compte du serveur de signalisation hébergé a changé le statut de \"{oldstatus}\" à \"{newstatus}\".",
    "pending" : "en attente",
    "active" : "actif",
    "expired" : "expiré",
    "blocked" : "bloqué",
    "error" : "erreur",
    "The certificate of {host} expires in {days} days" : "Le certificat de {host} expire dans {days} jours",
    "The certificate of {host} expired" : "Le certificat de  {host} a expiré",
    "Contact via Talk" : "Contacter via Talk",
    "Open Talk" : "Ouvrir Talk",
    "Default" : "Par défaut",
    "Presentation" : "Présentation",
    "Voice room" : "Salon vocal",
    "Conversations" : "Conversations",
    "Messages in current conversation" : "Messages dans la conversation actuelle",
    "{user}" : "{user}",
    "Messages" : "Messages",
    "{user} in {conversation}" : "{user} dans {conversation}",
    "Messages in other conversations" : "Messages dans les autres conversations",
    "One-to-one rooms always need to show the other users avatar" : "Les conversations en tête à tête nécessitent l'affichage des avatars des autres utilisateurs",
    "Invalid emoji character" : "Caractère emoji invalide",
    "Invalid background color" : "Couleur de fond invalide",
    "Avatar image is not square" : "L'image d'avatar n'est pas carré",
    "Room {number}" : "Salle {number}",
    "Other" : "Autre",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "La requête de période d'essai a échouée car le serveur d'essai est injoignable. Merci d'essayer plus tard. ",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Il y a un problème d'authentification de cette instance. Il est possible qu'elle ne soit pas accessible depuis l'extérieur pour vérifier son URL.",
    "Something unexpected happened." : "Quelque chose d’inattendu est survenu.",
    "The URL is invalid." : "L'adresse est invalide.",
    "An HTTPS URL is required." : "Une adresse HTTPS est exigée.",
    "The email address is invalid." : "L'adresse e-mail est invalide.",
    "The language is invalid." : "La langue est invalide.",
    "The country is invalid." : "Le pays est invalide.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Il y a un problème avec la requête de la période d'essai. Veuillez vérifier les logs pour de plus amples informations.",
    "Too many requests are send from your servers address. Please try again later." : "Trop de requêtes ont été envoyées depuis l'adresse de votre serveur. Veuillez essayer plus tard.",
    "There is already a trial registered for this Nextcloud instance." : "Il y a déjà un compte d'essai enregistré pour cette instance Nextcloud.",
    "Something unexpected happened. Please try again later." : "Quelque chose d’inattendu est survenu. Veuillez essayer plus tard.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "La requête de période d'essai a échouée car le comportement du serveur d'essai a été inapproprié. Merci d'essayer plus tard. ",
    "Trial requested but failed to get account information. Please check back later." : "La requête de période d'essai a été soumise mais n'a pas pu obtenir l'information sur le compte. Merci de vérifier à nouveau plus tard.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Il y a un problème d'authentification de cette requête. Il est possible qu'elle ne soit pas accessible depuis l'extérieur pour vérifier son URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "La récupération des informations du compte a échoué car le serveur d'essai se comporte étrangement. Veuillez essayer à nouveau plus tard.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Il y a un problème avec la récupération des informations du compte. Veuillez vérifier les logs pour de plus amples informations.",
    "There is no such account registered." : "Il n'y a pas de tel compte enregistré.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "La récupération des informations du compte a échoué car le serveur d'essai est injoignable. Veuillez essayer à nouveau plus tard.",
    "Deleting the hosted signaling server account failed. Please check back later." : "La suppression du compte du serveur de signal a échoué. Veuillez essayer à nouveau plus tard. ",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "La suppression du compte a échoué car le serveur d'essai se comporte étrangement. Veuillez essayer à nouveau plus tard.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Il y a un problème avec la suppression du compte. Veuillez vérifier les logs pour de plus amples informations.",
    "Too many requests are sent from your servers address. Please try again later." : "Trop de requêtes sont envoyées depuis l'adresse de votre serveur. Veuillez réessayer plus tard.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "La suppression du compte a échoué car le serveur d'essai est injoignable. Veuillez essayer à nouveau plus tard.",
    "Note to self" : "Note à soi-même",
    "A place for your private notes, thoughts and ideas" : "Un endroit pour vos notes privées, vos pensées et vos idées",
    "Transcript is AI generated and may contain mistakes" : "La retranscription est générée par une intelligence artificielle et peut contenir des erreurs",
    "Summary is AI generated and may contain mistakes" : "Le résumé est généré par une intelligence artificielle et peut contenir des erreurs.",
    "Let's get started!" : "Allons-y !",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** est une plateforme de communication sécurisé et auto-hébergée qui s'intègre complètement dans l'écosystème Nextcloud\n\n#### Fonctionnalités clés de Nextcloud Talk:\n\n* Chat et messagerie dans des groupes privés et publics\n* Appels audio et vidéo\n* Partage de fichiers et intégration avec d'autres applications Nextcloud\n* Paramètres de la conversation, modération et contrôle de la vie privée personnalisables\n* Client Web, de bureau et mobile (iOS et Android)\n* Communication sécurisée & privée\n\nPlus d'informations dans [la documentation utilisateur](https://docs.nextcloud.com/server/latest/user_manual/fr/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Bienvenue dans Nextcloud Talk\n\nNextcloud Talk est une application de messagerie instantanée puissante et privée qui s'intègre dans Nextcloud. Discutez avec des groupes publics et privés, collaborez avec des appels audio et vidéo, organisez des webinaires et des événements, personnalisez vos conversations et plus encore.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formater vos textes pour créer des messages mis en forme\n\nDans Nextcloud Talk, vous pouvez utiliser la syntaxe Markdown pour formater vos messages. Par exemple, appliquer un formatage **gras** ou *italique*, ou `présentez le texte comme du code`. Vous pouvez même créer des tableaux et ajouter des titres à votre texte.\n\nBesoin de corriger une faute de frappe ou changer la mise en forme ? Éditez votre message en cliquant \"Éditer le message\" dans le menu contextuel du message.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Ajoutez des liens et des pièces jointes\n\nAjoutez des fichiers depuis votre espace Nextcloud en utilisant le bouton \"+\". Partagez des éléments depuis Fichiers et d'autres applications Nextcloud. Certaines applications supportent même l'intégration interactive, par exemple l'application Text",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Suivez le flux des conversations : mentionnez les utilisateurs, réagissez à leur message et plus encore\n\nVous pouvez mentionner tout le monde dans la conversation en utilisant %s ou mentionner des participants spécifiques en tapant \"@\" et en sélectionnant leur nom dans la liste.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Vous pouvez répondre aux messages, les transférer dans d'autres conversations et à d'autres personnes, ou copier le contenu d'un message.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Faites-en encore plus avec le sélecteur intelligent\n\nTapez simplement \"/\" ou allez sur le menu \"+\" pour ouvrir le sélecteur intelligent où vous pouvez ajouter du contenu varié à vos messages. Vous pouvez configurer le sélecteur intelligent pour être capable d'ajouter des éléments d'autres applications Nextcloud, des GIFs, des cartes, du contenu généré par intelligence artificielle et bien d'autres encore.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Gérer les paramètres de conversattion\n\nDans le menu de la conversation, vous pouvez accéder à différents paramètres pour gérer vos conversations, comme : \n* Éditer les infos de la conversation\n* Gérer les notifications\n* Appliquer des règles de modération\n* Configurer l'accès et la sécurité\n* Activer des robots de conversation\n* et plus encore !",
    "Andorra" : "Andorre",
    "United Arab Emirates" : "Émirats Arabes Unis",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua et Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanie",
    "Armenia" : "Arménie",
    "Angola" : "Angola",
    "Antarctica" : "Antarctique",
    "Argentina" : "Argentine",
    "American Samoa" : "Samoa américaines",
    "Austria" : "Autriche",
    "Australia" : "Australie",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbaïdjan",
    "Bosnia and Herzegovina" : "Bosnie-Herzégovine",
    "Barbados" : " La Barbade",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgique",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarie",
    "Bahrain" : "Bahreïn",
    "Burundi" : "Burundi",
    "Benin" : "Bénin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : " Les Bermudes",
    "Brunei Darussalam" : "Brunei",
    "Bolivia, Plurinational State of" : "Bolivie, État plurinational de",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Saint-Eustache et Saba",
    "Brazil" : "Brésil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhoutan",
    "Bouvet Island" : "Île Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Biélorussie",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Îles Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Congo, République Démocratique du",
    "Central African Republic" : "République centrafricaine",
    "Congo" : "Congo",
    "Switzerland" : "Suisse",
    "Côte d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "Îles Cook",
    "Chile" : "Chili",
    "Cameroon" : "Cameroun",
    "China" : "Chine",
    "Colombia" : "Colombie",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cap-Vert",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Île Christmas",
    "Cyprus" : "Chypre",
    "Czechia" : "République tchèque",
    "Germany" : "Allemagne",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danemark",
    "Dominica" : "Dominique",
    "Dominican Republic" : "République Dominicaine",
    "Algeria" : "Algérie",
    "Ecuador" : "Équateur",
    "Estonia" : "Estonie",
    "Egypt" : "Égypte",
    "Western Sahara" : "Sahara occidental",
    "Eritrea" : "Érythrée",
    "Spain" : "Espagne",
    "Ethiopia" : "Éthiopie",
    "Finland" : "Finlande",
    "Fiji" : "Fidji",
    "Falkland Islands (Malvinas)" : "Îles Malouines (ou Falkland)",
    "Micronesia, Federated States of" : "Micronésie, États fédérés de",
    "Faroe Islands" : "Îles Féroé",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Royaume-Uni",
    "Grenada" : "Grenade",
    "Georgia" : "Géorgie",
    "French Guiana" : "Guyane française",
    "Guernsey" : "Guernesey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambie",
    "Guinea" : "Guinée",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinée Équatoriale",
    "Greece" : "Grèce",
    "South Georgia and the South Sandwich Islands" : "Géorgie du Sud et les îles Sandwich du Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinée-Bissau",
    "Guyana" : "Guyane",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Îles Heard-et-MacDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croatie",
    "Haiti" : "Haïti",
    "Hungary" : "Hongrie",
    "Indonesia" : "Indonésie",
    "Ireland" : "Irlande",
    "Israel" : "Israël",
    "Isle of Man" : "Île de Man",
    "India" : "Inde",
    "British Indian Ocean Territory" : "Territoire britannique de l'océan Indien",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran, République islamique d'",
    "Iceland" : "Islande",
    "Italy" : "Italie",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaïque",
    "Jordan" : "Jordanie",
    "Japan" : "Japon",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizstan",
    "Cambodia" : "Cambodge",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comores",
    "Saint Kitts and Nevis" : "Saint-Christophe-et-Niévès",
    "Korea, Democratic People's Republic of" : "Corée du Nord, République populaire et démocratique de",
    "Korea, Republic of" : "Corée, République de",
    "Kuwait" : "Koweït",
    "Cayman Islands" : "Îles Caïmans",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Laos, République démocratique populaire du",
    "Lebanon" : "Liban",
    "Saint Lucia" : "Sainte-Lucie",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituanie",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Lettonie",
    "Libya" : "Libye",
    "Morocco" : "Maroc",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldavie, République de",
    "Montenegro" : "Monténégro",
    "Saint Martin (French part)" : "Saint Martin (Partie française)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Îles Marshall",
    "North Macedonia" : "Macédoine du Nord",
    "Mali" : "Mali",
    "Myanmar" : "Birmanie",
    "Mongolia" : "Mongolie",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Îles Mariannes du Nord",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritanie",
    "Montserrat" : "Montserrat",
    "Malta" : "Malte",
    "Mauritius" : "Île Maurice",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mexique",
    "Malaysia" : "Malaisie",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibie",
    "New Caledonia" : "Nouvelle-Calédonie",
    "Niger" : "Niger",
    "Norfolk Island" : "Île Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Pays-Bas",
    "Norway" : "Norvège",
    "Nepal" : "Népal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nouvelle-Zélande",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Pérou",
    "French Polynesia" : "Polynésie française",
    "Papua New Guinea" : "Papouasie-Nouvelle-Guinée",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Pologne",
    "Saint Pierre and Miquelon" : "Saint Pierre et Miquelon",
    "Pitcairn" : "Île Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine, State of" : "Palestine, État de",
    "Portugal" : "Portugal",
    "Palau" : "Palaos",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Roumanie",
    "Serbia" : "Serbie",
    "Russian Federation" : "Russie, Fédération de",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabie Saoudite",
    "Solomon Islands" : "Îles Salomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Soudan",
    "Sweden" : "Suède",
    "Singapore" : "Singapour",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sainte-Hélène, Ascension et Tristan da Cunha",
    "Slovenia" : "Slovénie",
    "Svalbard and Jan Mayen" : "Svalbard et Jan Mayen",
    "Slovakia" : "Slovaquie",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "Saint Marin",
    "Senegal" : "Sénégal",
    "Somalia" : "Somalie",
    "Suriname" : "Suriname",
    "South Sudan" : "Soudan du Sud",
    "Sao Tome and Principe" : "Sao Tomé-et-Principe",
    "El Salvador" : "Salvador",
    "Sint Maarten (Dutch part)" : "Saint Martin (Partie néerlandaise)",
    "Syrian Arab Republic" : "Syrie, République Arabe Syrienne",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Îles Turques-et-Caïques",
    "Chad" : "Tchad",
    "French Southern Territories" : "Terres australes et antarctiques françaises",
    "Togo" : "Togo",
    "Thailand" : "Thaïlande",
    "Tajikistan" : "Tadjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor oriental",
    "Turkmenistan" : "Turkménistan",
    "Tunisia" : "Tunisie",
    "Tonga" : "Tonga",
    "Turkey" : "Turquie",
    "Trinidad and Tobago" : "Trinité-et-Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taïwan, Province de Chine",
    "Tanzania, United Republic of" : "Tanzanie, République unie de",
    "Ukraine" : "Ukraine",
    "Uganda" : "Ouganda",
    "United States Minor Outlying Islands" : "Îles mineures éloignées des États-Unis",
    "United States of America" : "États-Unis d'Amérique",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Ouzbékistan",
    "Holy See" : "Vatican",
    "Saint Vincent and the Grenadines" : "Saint Vincent et les Grenadines",
    "Venezuela, Bolivarian Republic of" : "Venezuela, République bolivarienne du",
    "Virgin Islands, British" : "Îles Vierges britanniques",
    "Virgin Islands, U.S." : "Îles Vierges des États-Unis",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis et Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yémen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Afrique du Sud",
    "Zambia" : "Zambie",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Flou d'arrière-plan",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Impossible de vérifier la prise en charge du chargement WASM. Veuillez vérifier manuellement si votre serveur Web sert des fichiers `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Votre serveur Web n'est pas correctement configuré pour fournir les fichiers `.wasm`. Il s'agit généralement d'un problème lié à la configuration de Nginx. Pour le flou d'arrière-plan, un ajustement est nécessaire pour fournir également les fichiers `.wasm`. Comparez votre configuration Nginx à la configuration recommandée dans notre documentation.",
    "Talk configuration values" : "Valeurs de configuration de Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Le forçage d'une durée d'appel n'est pris en charge qu'avec le système cron. Veuillez activer le système cron ou supprimer la configuration `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Les petites valeurs `max_call_duration` (actuellement définies sur %d) ne sont pas applicables en raison de limitations techniques. La tâche en arrière-plan n'est exécutée que toutes les 5 minutes, utilisez-la donc à vos risques et périls.",
    "Federation" : "Fédération",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Il est fortement recommandé de configurer \"memcache.locking\" lorsque Talk Federation est activé.",
    "High-performance backend" : "Infrastructure de haute performance",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Aucun serveur haute performance configuré - Utiliser Nextcloud Talk sans serveur haute performance n'est possible que pour les appels limités à quelques personnes (maximum 2-3 participants). Merci de configurer un serveur haute performance pour permettre des appels entre de multiples participants sans ralentissements.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "L'exécution du mode \"conversation_cluster\" du backend hautes performances est obsolète et ne sera plus prise en charge dans la prochaine version. Le backend hautes performances prend désormais en charge le clustering réel, qui devrait être utilisé à la place.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "La définition de plusieurs backends hautes performances est obsolète et ne sera plus prise en charge dans la prochaine version. À la place, un équilibreur de charge doit être configuré avec des serveurs de signalisation en cluster et configuré dans les paramètres Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "La clé publique utilisée par l’algorithme %1$s ne correspond pas avec la clé privée enregistrée. Exécutez %2$s pour corriger le problème.",
    "High-performance backend not configured correctly. Run %s for details." : "Le serveur Haute Performance n'est pas configuré correctement. Lancez %s pour plus de détails.",
    "High-performance backend not configured correctly" : "Serveur haute-performance non correctement configuré",
    "Error: Cannot connect to server" : "Erreur : impossible de se connecter au serveur",
    "Error: Server did not respond with proper JSON" : "Erreur: Le serveur n'a pas répondu avec un JSON correct",
    "Error: Certificate expired" : "Erreur : Certificat expiré",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Erreur : les horloges du serveur Nextcloud et du serveur haute performance sont désynchronisées. Merci de vous assurer que les deux serveurs sont connectés à un serveur de temps ou synchronisez manuellement leurs horloges.",
    "Could not get version" : "Impossible d'obtenir la version",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Erreur : version en cours {version} ; le serveur a besoin d'être mis à jour pour être compatible avec cette version de Talk",
    "Error: Server responded with: {error}" : "Erreur: Le serveur a répondu avec: {error}",
    "Error: Unknown error occurred" : "Erreur: Une erreur inconnue est survenue",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Attention : version actuelle : {version}; Le serveur ne supporte pas toutes les fonctionnalités de cette version de Talk , fonctionnalités manquantes : {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Il est fortement recommandé de configurer un cache mémoire lors de l'exécution de Nextcloud Talk avec un backend haute performance.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push est installé, cela améliore la ponctualité des notifications Talk.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} n'est pas installé. Cela peut entraîner un retard dans les notifications Talk.",
    "Recording backend" : "Moteur d'enregistrement",
    "Using the recording backend requires a High-performance backend." : "L'utilisation d'un serveur d'enregistrement nécessite un serveur haute-performance.",
    "No recording backend configured" : "Aucun serveur d'enregistrement configuré",
    "SIP configuration" : "Configuration SIP",
    "Using the SIP functionality requires a High-performance backend." : "L'utilisation de la fonctionnalité SIP nécessite un backend de hautes performances.",
    "No SIP backend configured" : "Aucun serveur SIP configuré",
    "Invalid date, date format must be YYYY-MM-DD" : "Date invalide, le format de date doit être YYYY-MM-DD",
    "Conversation not found" : "Discussion non trouvée",
    "Path is already shared with this conversation" : "Le chemin est déjà partagé avec cette conversation",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, conférence vidéo et audio utilisant WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Discussions instantanées, vidéo et audioconférence utilisant WebRTC\n\n* 💬 **Discussions instantanées** Nextcloud Talk est livré avec un simple chat texte, vous permettant de partager ou de téléverser des fichiers depuis votre application Nextcloud Fichiers ou votre appareil local et de mentionner d’autres participants.\n* 👥 **Appels privés, de groupe, publics et protégés par mot de passe !** Invitez quelqu’un, un groupe entier ou envoyez un lien public pour inviter à un appel.\n* 🌐 ''Discussions instantanées fédérées** Discutez avec d’autres utilisateurs Nextcloud sur leurs serveurs\n* 💻 **Partage d’écran !** Partagez votre écran avec les participants de votre appel.\n* 🚀 **Intégration avec d’autres applications Nextcloud comme Fichiers, Agenda, Statut utilisateur, Tableau de bord, Flux, Cartes, Sélecteur intelligent, Contacts, Deck et bien d’autres encore.\n* 🌉 **Synchronisation avec d’autres solutions de discussions instantanées** Avec [Matterbridge](https://github.com/42wim/matterbridge/) intégré à Talk, vous pouvez facilement synchroniser de nombreuses autres solutions de chat avec Nextcloud Talk et vice-versa.",
    "Leave call" : "Quitter l'appel",
    "Navigating away from the page will leave the call in {conversation}" : "En quittant cette page, vous quitterez l'appel dans {conversation}",
    "Stay in call" : "Rester en ligne",
    "Error occurred when getting the conversation information" : "Une erreur est survenue lors de la récupération des informations de la conversation",
    "Discuss this file" : "Discuter de ce fichier",
    "Share this file with others to discuss it" : "Partagez ce fichier avec d'autres personnes pour en discuter",
    "Share this file" : "Partager ce fichier",
    "Join conversation" : "Rejoindre la conversation",
    "This conversation is password-protected." : "Cette conversation est protégée par un mot de passe",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Nous avons détecté plusieurs tentatives de connexion invalides depuis votre adresse IP. Par conséquent, votre prochain tentative de connexion sera retardée de 30 secondes.",
    "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
    "Password" : "Mot de passe",
    "Submit" : "Soumettre",
    "Error requesting the password." : "Erreur lors de la demande du mot de passe",
    "Request password" : "Demande de mot de passe",
    "This conversation has ended" : "Cette conversation a pris fin",
    "Error occurred when joining the conversation" : "Une erreur est survenue au moment de rejoindre la conversation",
    "Close Talk sidebar" : "Fermer le panneau latéral de Talk",
    "Open Talk sidebar" : "Ouvrir le panneau latéral de Talk",
    "Everyone" : "Tout le monde",
    "Users and moderators" : "Utilisateurs et modérateurs",
    "Moderators only" : "Seulement les modérateurs",
    "Disable calls" : "Désactiver les appels",
    "Save changes" : "Enregistrer les modifications",
    "Saving …" : "Enregistrement...",
    "Saved!" : "Enregistré !",
    "Limit to groups" : "Limiter à des groupes",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Lorsqu'au moins un groupe est sélectionné, seules les personnes des groupes répertoriés peuvent participer aux conversations.",
    "Guests can still join public conversations." : "Les invités peuvent toujours rejoindre les conversations publiques.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Les utilisateurs qui ne peuvent plus utiliser Talk seront toujours listés comme participants dans leur précédentes conversations et leurs messages instantanés seront conservés.",
    "Limit using Talk" : "Limiter l'utilisation de Talk",
    "Limit creating a public and group conversation" : "Limiter la création de conversation publique et de groupe",
    "Limit creating conversations" : "Limiter la création de conversations",
    "Limit starting a call" : "Limiter le lancement d'appel",
    "Limit starting calls" : "Limiter le lancement  des appels",
    "When a call has started, everyone with access to the conversation can join the call." : "Lorsqu'un appel a commencé, toutes les personnes ayant accès à la conversation peuvent se joindre à l'appel.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Les robots suivants sont installés sur ce serveur. Dans la documentation vous pouvez trouver comment {linkstart1}construire votre propre robot{linkend} ou une {linkstart2}liste de robots{linkend} à activer sur votre serveur.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Aucun robot n'est installé sur ce serveur. Dans la documentation vous pouvez trouver comment {linkstart1}créer votre propre robot{linkend} ou une {linkstart2}liste de robots{linkend} à activer sur votre serveur.",
    "Description is not provided" : "Description non fournie",
    "Locked for moderators" : "Verrouillé pour les modérateurs",
    "Enabled" : "Activé",
    "Disabled" : "Désactivé",
    "Bots settings" : "Paramètres des robots",
    "State" : "État",
    "Name" : "Nom",
    "Last error" : "Dernière erreur",
    "Total errors count" : "Nombre total d'erreurs",
    "Find more bots" : "Chercher d'autres robots",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Les serveurs de confiance peuvent être configurés sur la {linkstart}page des paramètres de partage{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Les discussions et les appels fédérés fonctionnent déjà. La gestion des pièces jointes sera disponible dans une future version.",
    "Enable Federation in Talk app" : "Activer Fédération dans l'app Talk",
    "Permissions" : "Permissions",
    "Allow users to be invited to federated conversations" : "Autoriser les utilisateurs à être invité dans des conversations fédérées",
    "Allow users to invite federated users into conversation" : "Autoriser les utilisateurs à inviter des utilisateurs fédérées dans la conversation",
    "Only allow to federate with trusted servers" : "N'autoriser la fédération qu'avec les serveurs de confiance",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Lorsqu'au moins un groupe est sélectionné, seules les personnes des groupes répertoriés peuvent inviter des utilisateurs fédérés aux conversations.",
    "Groups allowed to invite federated users" : "Groupes autorisés à inviter des utilisateurs fédérés",
    "Select groups …" : "Sélectionner les groupes...",
    "All messages" : "Tous les messages",
    "@-mentions only" : "Seulement les mentions @",
    "Off" : "Désactiver",
    "General settings" : "Paramètres généraux",
    "Default notification settings" : "Paramètres de notification par défaut",
    "Default group notification" : "Notification de groupe par défaut",
    "Default group notification for new groups" : "Notification de groupe par défaut pour les nouveaux groupes",
    "Integration into other apps" : "Intégration dans d'autres applications",
    "Allow conversations on files" : "Autoriser les conversations sur les fichiers",
    "Allow conversations on public shares for files" : "Autoriser les conversations sur les partages publics pour les fichiers",
    "End-to-end encrypted calls" : "Appels chiffrés de bout en bout",
    "Enable encryption" : "Activer le chiffrement",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Les appels chiffrés de bout en bout avec une passerelle SIP nécessitent une nouvelle version du serveur haute-performance et de la passerelle SIP",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Les clients mobiles ne supportent pas les appels chiffrés de bout en bout pour le moment.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "En cliquant sur le bouton ci-dessus, les informations dans le formulaire sont envoyées aux serveurs de Struktur AG. Vous pouvez trouver plus d'informations ici : {linkstart}spreed.eu{linkend}.",
    "Pending" : "En attente",
    "Error" : "Erreur",
    "Blocked" : "Bloqué",
    "Active" : "Actif",
    "Expired" : "Expiré",
    "Never" : "Jamais",
    "The trial could not be requested. Please try again later." : "La période d'essai n'a pas pu être demandé. Veuillez réessayer plus tard.",
    "The account could not be deleted. Please try again later." : "Le compte n'a pas pu être supprimé. Veuillez réessayer plus tard.",
    "Hosted High-performance backend" : "Serveur haute performance hébergé",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Notre partenaire Struktur AG fournit un service dans lequel un serveur de signalisation hébergé peut être demandé. Pour cela il vous suffit de renseigner le formulaire ci-dessous et votre Nextcloud le demandera. Une fois le serveur configuré pour vous les identifiants seront automatiquement renseignés. Ceci écrasera les actuels réglages du serveur de signalement.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Si votre compte backend haute performance inclut les fonctionnalités STUN et/ou TURN, les paramètres seront mis à jour en conséquence.",
    "URL of this Nextcloud instance" : "URL de cette instance Nextcloud",
    "Full name of the user requesting the trial" : "Nom complet de l'utilisateur qui demande la période d'essai",
    "Email of the user" : "E-mail de l'utilisateur",
    "Language" : "Langue",
    "Country" : "Pays",
    "Request signaling server trial" : "Demande de période d'essai pour un serveur de signalement",
    "You can see the current status of your hosted signaling server in the following table." : "Vous pouvez voir le statut actuel de votre serveur de signalement hébergé dans le tableau suivant.",
    "Status" : "État",
    "Created at" : "Créé le",
    "Expires at" : "Expire à",
    "Limits" : "Limites",
    "STUN included" : "STUN inclus",
    "Yes" : "Oui",
    "No" : "Non",
    "TURN included" : "TURN inclus",
    "Delete the signaling server account" : "Supprimer le compte de serveur de signalisation",
    "_%n user_::_%n users_" : ["%n utilisateur","%n utilisateurs","%n utilisateurs"],
    "Installed version: {version}" : "Version installée : {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Vous pouvez installer Matterbridge pour relier Nextcloud Talk à d'autres services, visiter leur {linkstart1}page GitHub{linkend} pour plus de détails. Télécharger et installer l'application peut prendre un certain temps. Si cela échoue, merci de l'installer manuellement depuis le {linkstart2}magasin d'applications Nextcloud{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Le binaire Matterbridge a des permissions incorrectes. Merci de vous assurer que le binaire Matterbridge appartient au bon utilisateur et qu'il peut être exécuté. Il peut être trouvé dans \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Le binaire Matterbridge est introuvable ou n'a pas pu être exécuté.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Vous pouvez aussi définir le chemin vers le binaire Matterbridge manuellement via les options. Consultez la {linkstart}documentation d'intégration Matterbridge{linkend} pour plus d'information.",
    "Downloading …" : "Téléchargement …",
    "Install Talk Matterbridge" : "Installer Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Une erreur est survenue lors de l'installation de l'application Matterbridge.",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Une erreur est survenue lors de l'installation de Talk Matterbridge. Veuillez l'installer manuellement.",
    "Failed to execute Matterbridge binary." : "Impossible d'exécuter le binaire Matterbridge.",
    "Matterbridge integration" : "Intégration de Matterbridge",
    "Enable Matterbridge integration" : "Activer l'intégration de Matterbridge",
    "Status: Checking connection" : "Statut : vérification de la connexion...",
    "OK: Running version: {version}" : "OK : version actuelle : {version}",
    "Error: Server seems to be a Signaling server" : "Erreur : le serveur semble être un serveur de signalement",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Erreur : les horloges du serveur Nextcloud et du serveur d'enregistrement sont désynchronisées. Merci de vous assurer que les deux serveurs sont connectés à un serveur de temps ou synchronisez manuellement leurs horloges.",
    "Recording backend URL" : "URL du moteur d'enregistrement",
    "Validate SSL certificate" : "Valider le certificat SSL",
    "Delete this server" : "Supprimer ce serveur",
    "Test this server" : "Tester ce serveur",
    "Disabled for all calls" : "Désactivé pour tous les appels",
    "Enabled for all calls" : "Activé pour tous les appels",
    "Configurable on conversation level by moderators" : "Configuration au niveau de la conversation par les modérateurs",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Les paramètres PHP \"upload_max_filesize\" ou \"post_max_size\" permettront de ne téléverser que des fichiers jusqu'à {maxUpload}.",
    "Recording backend settings saved" : "Paramètres du moteur d'enregistrement enregistrés",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Les modérateurs seront autorisés à activer le consentement au niveau de la conversation. Le consentement à être enregistré sera exigé pour chaque participant avant de rejoindre n'importe quel appel dans cette conversation.",
    "The consent to be recorded will be required for each participant before joining every call." : "Le consentement à être enregistré sera exigé pour chaque participant avant de rejoindre n'importe quel appel.",
    "The consent to be recorded is not required." : "Le consentement à être enregistré n'est pas exigé.",
    "Recording backend configuration is only possible with a High-performance backend." : "La configuration d'un serveur d'enregistrement est possible seulement avec un serveur haute performance.",
    "Add a new recording backend server" : "Ajouter un nouveau moteur d'enregistrement",
    "Shared secret" : "Secret partagé",
    "Recording consent" : "Consentement à l'enregistrement",
    "Recording transcription" : "Enregistrement de la transcription",
    "Automatically transcribe call recordings with a transcription provider" : "Transcrire automatiquement les enregistrements avec un fournisseur de transcription",
    "Automatically summarize call recordings with transcription and summary providers" : "Résumer automatiquement les enregistrements avec des fournisseurs de résumé et de transcription",
    "SIP configuration saved!" : "Configuration SIP sauvegardée !",
    "SIP configuration is only possible with a High-performance backend." : "La configuration SIP n'est possible qu'avec un serveur haute performance.",
    "Enable SIP Dial-out option" : "Activer l'option de composition SIP",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Le serveur de signalement doit être mis à jour pour supporter la fonctionnalité de composition SIP",
    "Do not show SIP Dial-out caller number" : "Ne pas afficher le numéro de l'appelant SIP sortant",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Le numéro anonyme doit apparaître comme \"inconnu\" ou \"numéro masqué\" pour appeler le destinataire.",
    "Dial-out number" : "Numéro sortant",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Numéro au format E164 utilisé comme numéro d'appelant de secours pour les appels sortants",
    "Dial-out prefix" : "Préfixe de numérotation sortante",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Préfixe ajouté au numéro d'utilisateur configuré pour les appels sortants (la valeur par défaut est \"+\")",
    "Restrict SIP configuration" : "Restreindre la configuration SIP",
    "Enable SIP configuration" : "Activer la configuration SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Seuls les utilisateurs des groupes suivants peuvent activer SIP dans les conversations dont ils sont modérateurs",
    "Phone number (Country)" : "Numéro de téléphone (pays)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Cette information est présente dans les e-mails d'invitation et affichée à tous les participants dans le panneau latéral.",
    "Nextcloud base URL" : "URL de base de Nextcloud",
    "Talk Backend URL" : "URL du serveur Talk",
    "WebSocket URL" : "URL de la WebSocket",
    "Available features" : "Fonctionnalités disponibles",
    "Error: Websocket connection failed" : "Erreur : Connexion Websocket échouée",
    "Error code" : "Code d'erreur",
    "Error message" : "Message d'erreur",
    "Error: Websocket connection failed. Check browser console" : "Erreur : La connexion à la WebSocket a échoué. Vérifier la console web.",
    "High-performance backend URL" : "URL vers l'infrastructure de haute performance",
    "Missing High-performance backend warning hidden" : "Avertissement sur l'absence de serveur haute performance caché",
    "High-performance backend settings saved" : "Paramètres du serveur haute performance sauvegardés",
    "Nextcloud Talk setup not complete" : "La configuration de Nextcloud Talk n'est pas terminée",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Merci de noter que lors des appels avec plus de 2 participants sans le serveur haute performance, les participants vont vraisemblablement subir des latences et leurs appareils une charge importante.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Installer le serveur haute performance pour que les appels avec de multiples participants fonctionnent sans ralentissement.",
    "Nextcloud portal" : "Portail Nextcloud",
    "Quick installation guide" : "Guide d'installation rapide",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Un serveur haute performance est requis pour les appels et conversations avec de multiples participants. Sans ce serveur, tous les participants doivent envoyer leur propre vidéo à tous les autres participants, ce qui causera probablement des problèmes de latence et une charge importante sur les appareils des participants.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Il est hautement recommandé de configurer un cache distribué quand vous utilisez Nextcloud Talk avec un serveur haute performance.",
    "Add High-performance backend server" : "Ajouter un serveur haute performance",
    "Warn about connectivity issues in calls with more than 2 participants" : "Avertir à propos des problèmes de connectivité dans les appels avec plus de 2 participants",
    "STUN server URL" : "URL du serveur STUN",
    "The server address is invalid" : "L'adresse du serveur est invalide",
    "STUN settings saved" : "Paramètres STUN sauvegardés",
    "STUN servers" : "Serveurs STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un serveur STUN est utilisé pour déterminer l'adresse publique des participants situés derrière un routeur.",
    "Add a new STUN server" : "Ajouter un nouveau serveur STUN",
    "{schema} scheme must be used with a domain" : "Le schéma {schema} doit être utilisé avec un domaine",
    "{option1} and {option2}" : "{option1} et {option2}",
    "{option} only" : "{option} seulement",
    "OK: Successful ICE candidates returned by the TURN server" : "OK : Le serveur TURN a retourné des candidats ICE avec succès",
    "Error: No working ICE candidates returned by the TURN server" : "Erreur : Le serveur TURN n'a pas retourné de candidats ICE  fonctionnels",
    "Testing whether the TURN server returns ICE candidates" : "En cours de test du retour de candidats ICE par le serveur TURN",
    "TURN server schemes" : "Schémas du serveur TURN",
    "TURN server URL" : "URL du serveur TURN",
    "TURN server secret" : "Mot de passe du serveur TURN",
    "TURN server protocols" : "Protocoles du serveur TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Un serveur TURN est utilisé comme proxy pour les participants derrière un parefeu. Si des participants ne peuvent pas se connecter avec les autres, un serveur TURN est très probablement nécessaire. Consultez {linkstart}cette documentation{linkend} pour les instructions de configuration.",
    "TURN settings saved" : "Paramètres TURN sauvegardés",
    "TURN servers" : "Serveurs TURN",
    "Add a new TURN server" : "Ajouter un nouveau serveur TURN",
    "Failed" : "Échec",
    "OK" : "OK",
    "Checking …" : "Vérification...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Échec : WebAssembly est désactivé ou n'est pas supporté dans ce navigateur. Merci d'activer WebAssembly ou d'utiliser un navigateur compatible pour lancer la vérification.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Échec : les fichiers « .wasm » et « .tflite » ne sont pas traités correctement par le serveur web. Merci de vérifier la section « Pré-requis techniques » de la documentation de Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK : les fichiers \".wasm\" et \".tflite\" ont été correctement renvoyés par le serveur web.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Il semble que la configuration Apache et PHP n'est pas compatible. Veuillez noter que PHP peut seulement être utilisé avec le module MPM_PREFORK et PHP-FPM peut seulement être utilisé avec le module MPM_EVENT",
    "Web server setup checks" : "Vérification de la configuration du serveur web",
    "Files required for virtual background can be loaded" : "Les fichiers nécessaires à l'arrière-plan virtuel peuvent être chargés",
    "Federated user" : "Utilisateur fédéré",
    "Assign participants to rooms" : "Assigner les participants aux salles",
    "Configure breakout rooms" : "Configurer les salles de sous-groupes",
    "Number of breakout rooms" : "Nombre de salles de sous-groupes",
    "You can create from 1 to 20 breakout rooms." : "Vous pouvez créer entre 1 et 20 salles de discussion.",
    "Assignment method" : "Méthode d'affectation",
    "Automatically assign participants" : "Assigner automatiquement les participants",
    "Manually assign participants" : "Assigner manuellement les participants",
    "Allow participants to choose" : "Autoriser les participants à choisir",
    "Create rooms" : "Créer une salle",
    "Confirm" : "Confirmer",
    "Create breakout rooms" : "Créer des salles de sous-groupes",
    "Reset" : "Réinitialiser",
    "Delete breakout rooms" : "Supprimer les salles de sous-groupes",
    "Room {roomNumber}" : "Salle {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Les salles de sous-groupes actuelles et leurs paramètres seront perdus",
    "Cancel" : "Annuler",
    "Unassigned participants" : "Participants non attribués",
    "Back" : "Retour",
    "Assign" : "Attribuer",
    "Add participant \"{user}\"" : "Ajouter le participant \"{user}\"",
    "Now" : "Maintenant",
    "Invalid calendar selected" : "Calendrier sélectionné invalide",
    "Invalid start time selected" : "Date de début sélectionnée invalide",
    "Invalid end time selected" : "Date de fin sélectionnée invalide",
    "Unknown error occurred" : "Une erreur inconnue est survenue",
    "Sending no invitations" : "Envoi d'aucune invitation",
    "{participant0} will receive an invitation" : "{participant0} va recevoir une invitation",
    "{participant0} and {participant1} will receive invitations" : "{participant0} et {participant1} vont recevoir une invitation",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} et %n autre vont recevoir des invitations","{participant0}, {participant1} et %n autres vont recevoir des invitations","{participant0}, {participant1} et %n autres vont recevoir des invitations"],
    "Invite {user}" : "Inviter {user}",
    "Invite all users and emails in this conversation" : "Inviter tous les utilisateurs et emails de cette conversation",
    "Meeting created" : "Réunion créée",
    "Upcoming meetings" : "Réunions à venir",
    "Loading …" : "Chargement…",
    "No upcoming meetings" : "Pas de réunion à venir",
    "Schedule a meeting" : "Planifier une réunion",
    "Meeting title" : "Objet de la réunion",
    "From" : "De",
    "To" : "À",
    "Calendar" : "Agenda",
    "Attendees" : "Participants",
    "No other participants to send invitations to." : "Pas d'autres participants à qui envoyer des invitations.",
    "Add attendees" : "Ajouter des participants",
    "Save" : "Enregistrer",
    "Search participants" : "Rechercher les participants",
    "No results" : "Aucun résultat",
    "Done" : "Fait",
    "Disable live transcription" : "Désactiver la transcription en direct",
    "Disable live translation" : "Désactiver la traduction en direct",
    "Original language: {languageName}" : "Langue d'origine : {languageName}",
    "Translated language" : "Langue traduite",
    "Translated language: {languageName}" : "Langue traduite : {languageName}",
    "Raise hand" : "Lever la main",
    "Raise hand (R)" : "Lever la main (R)",
    "Lower hand" : "Baisser la main",
    "Lower hand (R)" : "Baisser la main (R)",
    "Exit full screen (F)" : "Quitter le mode plein écran (F)",
    "Full screen (F)" : "Mode plein écran (F)",
    "Speaker view" : "Vue intervenant",
    "Grid view" : "Vue en grille",
    "Error when trying to load the available live transcription languages" : "Erreur lors du chargement des langues disponibles pour la transcription en direct",
    "Failed to enable live transcription" : "Échec de l'activation de la transcription en direct",
    "Failed to enable live translations" : "Échec de l'activation des traductions en direct",
    "Failed to disable live translations" : "Échec de la désactivation des traductions en direct",
    "Recording consent is required" : "Le consentement à l'enregistrement est requis",
    "This conversation is read-only" : "Cette conversation est en lecture seule",
    "Conversation not found or not joined" : "Conversation introuvable ou non jointe",
    "Lobby is still active and you're not a moderator" : "La salle d'attente est toujours active et vous n'êtes pas modérateur",
    "Connection failed" : "Échec de la connexion",
    "Reload" : "Recharger",
    "{nickName} raised their hand." : "{nickName} a levé la main.",
    "A participant raised their hand." : "Un participant a levé la main.",
    "Collapse stripe" : "Réduire le bandeau",
    "Expand stripe" : "Étendre le bandeau",
    "Previous page of videos" : "Page précédente de vidéos",
    "Next page of videos" : "Page suivante de vidéos",
    "Connecting …" : "Connexion …",
    "Calling …" : "Appel en cours...",
    "Waiting for {user} to join the call" : "En attente de l'arrivée de {user}",
    "Waiting for others to join the call …" : "En attente que les autres rejoignent l'appel…",
    "You can invite others in the participant tab of the sidebar" : "Vous pouvez inviter d'autres personnes dans l'onglet des participants du panneau latéral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Vous pouvez inviter d'autres personnes dans l'onglet des participants du panneau latéral ou partager ce lien pour inviter d'autres personnes !",
    "Share this link to invite others!" : "Partagez ce lien pour inviter les autres !",
    "Copy link" : "Copier le lien",
    "You are not allowed to enable audio" : "Vous n'êtes pas autorisé à activer l'audio",
    "No audio. Click to select device" : "Pas d'audio. Cliquez pour sélectionner le périphérique",
    "Mute audio" : "Couper le son",
    "Mute audio (M)" : "Couper le son (M)",
    "Unmute audio" : "Activer le son",
    "Unmute audio (M)" : "Activer le son (M)",
    "None" : "Aucun",
    "Select a microphone" : "Sélectionner un microphone",
    "Select a speaker" : "Sélectionner un haut-parleur",
    "Microphone settings" : "Réglages du microphone",
    "Check devices" : "Vérifier les périphériques",
    "Access to camera was denied" : "L'accès à la caméra a été refusé",
    "Error while accessing camera: It is likely in use by another program" : "Erreur en essayant d'accéder à la caméra : elle est probablement utilisée par un autre programme",
    "Error while accessing camera" : "Erreur en accédant à la caméra",
    "You have been muted by a moderator" : "Vous avez été rendu·e muet par un modérateur. ",
    "Hide presenter video" : "Masquer la vidéo du présentateur",
    "You are not allowed to enable video" : "Vous n'êtes pas autorisé à activer la vidéo",
    "No video. Click to select device" : "Pas d'audio. Cliquez pour sélectionner le périphérique",
    "Disable video" : "Désactiver la vidéo",
    "Disable video (V)" : "Désactiver la vidéo (V)",
    "Enable video" : "Activer la vidéo",
    "Enable video (V)" : "Activer la vidéo (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Activer la vidéo. Votre connexion va être brièvement interrompue lors de l'activation de la vidéo pour la première fois",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Activer la vidéo (V) - La conversation est brièvement interrompue lorsque vous activez la vidéo pour la première fois.",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Activer la vidéo. Votre connexion sera brièvement interrompue lorsque vous activez la vidéo pour la première fois.",
    "Select a video device" : "Sélectionner une caméra",
    "Show presenter" : "Afficher le présentateur",
    "You" : "Vous",
    "Mute" : "Mettre en sourdine",
    "Muted" : "Mis en sourdine",
    "Show screen" : "Afficher l'écran",
    "Stop following" : "Arrêter de suivre",
    "Connection could not be established …" : "La connexion n'a pas pu être établie...",
    "Connection was lost and could not be re-established …" : "La connexion a été perdue et n'a pas pu être rétablie...",
    "Connection could not be established. Trying again …" : "La connexion n'a pas pu être établie. Nouvelle tentative...",
    "Connection lost. Trying to reconnect …" : "Connexion perdue. Tentative de reconnexion...",
    "Connection problems …" : "Problèmes de connexion...",
    "Collapse" : "Replier",
    "Expand" : "Étendre",
    "You need to be logged in to upload files" : "Vous devez être connecté pour téléverser des fichiers",
    "Drop your files to upload" : "Glissez vos fichiers pour les téléverser",
    "Conversation messages" : "Messages de la conversation",
    "Scroll to bottom" : "Défiler jusqu'en bas",
    "Post message" : "Envoyer le message",
    "Federated conversation" : "Conversation fédérée",
    "Public conversation" : "Conversation publique",
    "Favorite" : "Favori",
    "Banned users" : "Utilisateurs bannis",
    "Manage the list of banned users in this conversation." : "Gérer les utilisateurs bannis de cette conversation",
    "Manage bans" : "Gestion des bannissements",
    "No banned users" : "Aucun utilisateur banni",
    "Banned by:" : "Banni par : ",
    "Date:" : "Date :",
    "Note:" : "Note :",
    "Hide details" : "Masquer les détails",
    "Show details" : "Afficher les détails",
    "Unban" : "Débloquer",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Vous pouvez changer le titre et la description dans l'application {linkstart}Agenda ↗{linkend}.",
    "Error while updating conversation name" : "Erreur lors de la mise à jour du nom de la conversation",
    "Error while updating conversation description" : "Erreur lors de la mise à jour de la description de la conversation",
    "Enter a name for this conversation" : "Saisissez un nom pour cette conversation",
    "Edit conversation name" : "Modifier le nom de la conversation",
    "Edit conversation description" : "Modifier la description de la conversation",
    "Enter a description for this conversation" : "Ajoutez une description à cette conversation",
    "Picture" : "Image",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Les robots suivants peuvent être activés dans cette conversation. Contactez votre administrateur pour installer d'autres robots sur ce serveur.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Aucun robot n'est installé sur ce serveur. Contactez votre administrateur pour installer des robots sur ce serveur.",
    "Disable" : "Désactiver",
    "Enable" : "Activer",
    "Breakout rooms" : "Salles de sous-groupes",
    "Manage breakout rooms" : "Gérer les salles de sous-groupes",
    "Set up breakout rooms for this conversation" : "Configurer les salles de sous-groupes pour cette conversation",
    "Please select a valid PNG or JPG file" : "Veuillez sélectionner un fichier PNG ou JPG valide.",
    "Choose your conversation picture" : "Choisir votre icône de conversation",
    "Choose" : "Choisir",
    "Error setting conversation picture" : "Erreur à la définition de l'icône de conversation",
    "Could not set the conversation picture: {error}" : "Impossible de définir l'icône de conversation : {error}",
    "Error cropping conversation picture" : "Erreur au redimensionnement de l'icône de conversation",
    "Error removing conversation picture" : "Erreur à la suppression de l'icône de conversation",
    "Set emoji as conversation picture" : "Définir l'emoji comme icône de la conversation",
    "Set background color for conversation picture" : "Définir la couleur de fond pour l'icône de la conversation",
    "Upload conversation picture" : "Téléverser une image de conversation",
    "Choose conversation picture from files" : "Choisir une image de conversation depuis Fichiers",
    "Remove conversation picture" : "Supprimer l'image de conversation",
    "The file must be a PNG or JPG" : "Le fichier doit être au format PNG ou JPG",
    "Set picture" : "Définir l'image",
    "Default permissions modified for {conversationName}" : "Permissions par défaut modifiées pour {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Impossible de modifier les permissions par défaut pour {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Modification des permissions par défaut pour les participants de cette conversation. Ces paramètres n'affectent pas les modérateurs.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Chaque fois que les permissions sont modifiées dans cette section, les permissions personnalisées précédemment attribuées aux participants individuellement seront écrasées.",
    "All permissions" : "Toutes les permissions",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Les participants ont le droit de lancer un appel, de rejoindre un appel, d'activer l'audio et la vidéo et de partager leur écran.",
    "Restricted" : "Restreint",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Les participants ont le droit de rejoindre un appel, mais ils ne peuvent ni activer l'audio et la vidéo, ni partager leur écran tant qu'un modérateur ne leur donne pas manuellement la permission de le faire.",
    "Advanced permissions" : "Permissions avancées",
    "Edit permissions" : "Modifier les permissions",
    "Conversation settings" : "Paramètres de la conversation",
    "Basic Info" : "Informations de base",
    "Personal" : "Personnel",
    "Moderation" : "Modération",
    "Setup overview" : "Aperçu de la configuration",
    "Live transcription" : "Transcription en direct",
    "Enable live transcription" : "Activer la transcription en direct",
    "Breakout Rooms" : "Salles de sous-groupes",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Robots",
    "Danger zone" : "Zone de danger",
    "Archive conversation" : "Archiver la conversation",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Les conversations archivées sont cachés de la liste des conversations par défaut. Cependant, elles continueront d'apparaître quand vous recherchez une conversation par son nom ou accédez à une liste de conversations archivées.",
    "Do you really want to leave \"{displayName}\"?" : "Voulez-vous vraiment quitter \"{displayName}\"?",
    "You can archive this conversation instead." : "Vous pouvez plutôt archiver cette conversation.",
    "Leave conversation" : "Quitter la conversation",
    "You need to promote a new moderator before you can leave the conversation" : "Vous devez promouvoir un nouveau modérateur avant de pouvoir quitter la conversation.",
    "Delete conversation" : "Supprimer la conversation",
    "Do you really want to delete \"{displayName}\"?" : "Souhaitez-vous réellement supprimer \"{displayName}\" ?",
    "Error while deleting conversation" : "Erreur lors de la suppression d'une conversation",
    "Delete all chat messages" : "Suppression de tous les messages instantanés",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Voulez-vous vraiment supprimer tous les messages dans « {displayName} » ?",
    "Error while clearing chat history" : "Erreur lors de la suppression de l'historique de messagerie",
    "Be careful, these actions cannot be undone." : "Attention, ces actions ne peuvent être annulées.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Après avoir quitté la conversation, une invitation est nécessaire pour rejoindre une conversation privée. Une conversation ouverte peut être rejointe à tout moment.",
    "Permanently delete this conversation." : "Supprimer définitivement cette conversation",
    "Delete chat messages" : "Supprimer les messages instantanés",
    "Permanently delete all the messages in this conversation." : "Supprimer définitivement tous les messages de cette conversation",
    "_%n hour_::_%n hours_" : ["%n heure","%n heures","%n heures"],
    "_%n day_::_%n days_" : ["%n jour","%n jours","%n jours"],
    "_%n week_::_%n weeks_" : ["%n semaine","%n semaines","%n semaines"],
    "Custom expiration time" : "Délai d'expiration personnalisé",
    "Message expiration disabled" : "L'expiration des messages est désactivée",
    "Message expiration set: {duration}" : "Délai d'expiration des messages défini : {duration}",
    "Error when trying to set message expiration" : "Erreur au paramétrage de l'expiration du message",
    "Message expiration" : "Expiration du message",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Les messages instantanés peuvent expirer après un certain temps. Note : les fichiers partagés dans la discussion ne seront pas effacés pour leur propriétaire, mais ils ne seront plus partagés dans la conversation.",
    "Set message expiration" : "Configurer l'expiration du message",
    "Current message expiration" : "Expiration du message actuel",
    "Password copied to clipboard" : "Mot de passe copié dans le presse-papiers",
    "Password could not be copied" : "Le mot de passe n'a pas pu être copié",
    "Guest access" : "Accès invité",
    "Breakout rooms are not allowed in public conversations." : "Les salles de sous-groupes ne sont pas autorisées dans les conversations publiques.",
    "Allow guests to join this conversation via link" : "Autoriser les invités à joindre cette conversation par un lien",
    "Password protection" : "Protection par mot de passe",
    "This conversation is password-protected. Guests need password to join" : "Cette conversation est protégée par un mot de passe. Les invités ont besoin d'un mot de passe pour la rejoindre",
    "Password protection is needed for public conversations" : "La protection par mot de passe est nécessaire pour les conversations publiques",
    "Set a password" : "Saisir un mot de passe",
    "Change password" : "Modifier le mot de passe",
    "Enter new password" : "Saisir un nouveau mot de passe",
    "Save password" : "Enregistrer le mot de passe",
    "Copy password" : "Copier le mot de passe",
    "Guests are allowed to join this conversation via link" : "Les invités sont autorisés à rejoindre cette conversation via un lien",
    "Guests are not allowed to join this conversation" : "Les invités ne sont pas autorisés à rejoindre cette conversation",
    "Resend invitations" : "Renvoyer les invitations",
    "This conversation is open to both registered users and users created with the Guests app" : "Cette conversation est ouvert aux utilisateurs enregistrés et aux utilisateurs créés avec l'application Invités",
    "This conversation is open to registered users" : "Cette conversation est ouverte aux utilisateurs enregistrés",
    "This conversation is limited to the current participants" : "La conversation est limitée aux participants actuels",
    "You opened the conversation to both registered users and users created with the Guests app" : "Vous avez ouvert la conversation aux utilisateurs enregistrés et aux utilisateurs créés avec l'application Invités",
    "Error occurred when opening or limiting the conversation" : "Une erreur est survenue lors de l'ouverture ou de la limitation de la conversation",
    "Open conversation to registered users, showing it in search results" : "Ouvrir la conversation aux utilisateurs enregistrés, en la montrant dans les résultats de recherche",
    "Also open to users created with the Guests app" : "Aussi ouvrir aux utilisateurs créés avec l'application Invités",
    "Open conversation" : "Ouvrir la conversation",
    "Set language spoken in calls" : "Définir la langue des appels",
    "Languages could not be loaded" : "Les langues n'ont pas pu être chargées",
    "Loading languages …" : "Chargement des langues...",
    "Invalid language" : "Langue non valide",
    "Default language (English)" : "Langue par défaut (Anglais)",
    "Default live transcription language set" : "Langue par défaut de la transcription en direct définie",
    "Live transcription language set: {languageName}" : "Langue de la transcription en direct définie : {languageName}",
    "Error when trying to set live transcription language" : "Erreur lors de la configuration de la langue de transcription en direct",
    "Start time: {date}" : "Heure de début : {date}",
    "Start time has been updated" : "L'heure de début a été mise à jour",
    "Error occurred while updating start time" : "Une erreur est survenue lors de la mise à jour de l'heure de début",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Activer la salle d'attente va retirer les non-modérateurs de l'appel en cours.",
    "Enable lobby, restricting the conversation to moderators" : "Activer la salle d'attente, restreignant la conversation aux modérateurs",
    "Meeting start time" : "Heure de début de la réunion",
    "Start time (optional)" : "Heure de début (optionnelle)",
    "Import email participants" : "Importer des adresses e-mail de participants",
    "You can import a list of email participants from a CSV file." : "Vous pouvez importer une liste d'adresses e-mail de participants depuis un fichier CSV.",
    "Poll drafts" : "Brouillons de sondage",
    "Browse poll drafts" : "Parcourir les brouillons de sondage",
    "Error occurred when locking the conversation" : "Une erreur est survenue lors du verrouillage de la conversation",
    "Error occurred when unlocking the conversation" : "Une erreur est survenue lors du déverrouillage de la conversation",
    "Lock conversation" : "Verrouiller la conversation",
    "This will also terminate the ongoing call." : "Cela mettra également fin à l'appel en cours.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Verrouiller la conversation pour éviter que quiconque n'écrive des messages ou ne lance des appels",
    "Edit" : "Modifier",
    "More information" : "Plus d'informations",
    "Delete" : "Effacer",
    "Add new bridged channel to current conversation" : "Ajouter un nouveau canal ponté à la conversation en cours",
    "unknown state" : "état inconnu",
    "running" : "en cours",
    "not running, check Matterbridge log" : "not running, check Matterbridge log",
    "not running" : "inactif",
    "Bridge saved" : "Lien enregistré",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Vous pouvez lier des salles de plusieurs autres systèmes de messagerie instantanée avec Matterbridge.",
    "More info on Matterbridge" : "Plus d'informations sur Matterbridge",
    "Messaging systems" : "Systèmes de messagerie",
    "Enable bridge" : "Activer le pont",
    "Show Matterbridge log" : "Afficher le log Matterbridge",
    "Log content" : "Contenu du registre",
    "Only moderators are allowed to mention @all" : "Seuls les modérateurs peuvent mentionner @all",
    "All participants are allowed to mention @all" : "Tous les participants peuvent mentionner @all",
    "Participants are now allowed to mention @all." : "Les participants sont maintenant autorisés à mentionner @all.",
    "Mentioning @all has been limited to moderators." : "Seuls les modérateurs ont été autorisés à mentionner @all.",
    "Allow participants to mention @all" : "Permettre aux participants de mentionner @all",
    "Mention permissions" : "Permissions de mention",
    "Notifications" : "Notifications",
    "Notify about calls in this conversation" : "Notification pour les appels de cette conversation",
    "Important conversation" : "Conversation importante",
    "\"Do not disturb\" user status is ignored for important conversations" : "Le statut utilisateur  \"Ne pas déranger\" est ignoré pour les conversations importantes.",
    "Sensitive conversation" : "Conversation sensible",
    "Message preview will be disabled in conversation list and notifications" : "La prévisualisation des messages sera désactivée dans la liste des conversations et les notifications",
    "Recording consent is required for calls in this conversation" : "Le consentement à l'enregistrement est exigé pour les appels dans cette conversation",
    "Recording consent is not required for calls in this conversation" : "Le consentement à l'enregistrement n'est pas exigé pour les appels dans cette conversation",
    "Recording consent requirement was updated" : "L'exigence de consentement à l'enregistrement a été mis à jour",
    "Error occurred while updating recording consent" : "Une erreur est survenue lors de la mise à jour du consentement à l'enregistrement",
    "Recording Consent" : "Consentement à l'enregistrement",
    "Recording consent cannot be changed once a call or breakout session has started." : "Le consentement à l'enregistrement ne peut pas être modifié lorsque l'appel ou une salle en sous-groupe a commencé. ",
    "Require recording consent before joining call in this conversation" : "Exiger le consentement à l'enregistrement avant de rejoindre l'appel dans cette conversation",
    "Recording consent is required for all calls" : "Le consentement à l'enregistrement est exigé pour tous les appels",
    "SIP dial-in is now possible without PIN requirement" : "La numérotation SIP est maintenant possible sans code PIN",
    "SIP dial-in is now enabled" : "La numérotation SIP est maintenant activée",
    "SIP dial-in is now disabled" : "La numérotation SIP est maintenant désactivée",
    "Error occurred when enabling SIP dial-in" : "Une erreur est survenue lors de l'activation de la numérotation SIP",
    "Error occurred when disabling SIP dial-in" : "Une erreur est survenue lors de la désactivation de la numérotation SIP",
    "Phone and SIP dial-in" : "Numérotation téléphonique et SIP",
    "Enable phone and SIP dial-in" : "Activer la numérotation téléphonique et SIP",
    "Allow to dial-in without a PIN" : "Autoriser la numérotation sans code PIN",
    "Ongoing" : "En cours",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n personne a accepté","%n personnes ont accepté","%n personnes ont accepté"],
    "_%n person declined_::_%n people declined_" : ["%n personne a décliné","%n personnes ont décliné","%n personnes ont décliné"],
    "_and %n other attachment_::_and %n other attachments_" : ["et %n autre pièce jointe","et %n autres pièces jointes","et %n autres pièces jointes"],
    "With {displayName}" : "Avec {displayName}",
    "In {conversation}" : "Dans {conversation}",
    "View attachment" : "Voir la pièce jointe",
    "Join" : "Rejoindre",
    "View conversation" : "Voir la conversation",
    "View event on Calendar" : "Voir l'événement dans l'Agenda",
    "Error while creating the conversation" : "Erreur lors de la création de la conversation",
    "Hello, {displayName}" : "Bonjour, {displayName}",
    "Start meeting now" : "Commencer une réunion maintenant",
    "Give your meeting a title" : "Donnez un titre à votre réunion",
    "Create and copy link" : "Créer et copier le lien",
    "Create a new conversation" : "Créer une nouvelle conversation",
    "Join open conversations" : "Rejoindre des conversations publiques",
    "Call a phone number" : "Appeler un numéro de téléphone",
    "Scroll backward" : "Défiler vers l'arrière",
    "Scroll forward" : "Défiler vers l'avant",
    "Schedule meetings" : "Planifier des réunions",
    "You don't have any upcoming meetings" : "Vous n'avez aucune réunion prévue",
    "Open calendar" : "Ouvrir l'agenda",
    "Unread mentions" : "Mentions non lues",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Les messages dans lesquels vous avez été mentionné·e s'afficheront ici. Vous pouvez mentionner des personnes en tapant @ suivi de leur nom.",
    "Upcoming reminders" : "Rappels à venir",
    "Message reminders" : "Rappels de messages",
    "Set a reminder on a message to be notified" : "Définir un rappel sur un message pour être averti",
    "Start a group conversation" : "Commencer une conversation de groupe",
    "Create conversation" : "Créer la conversation",
    "Enter your name" : "Saisissez votre nom",
    "Submit name and join" : "Valider le nom et rejoindre",
    "Do you already have an account?" : "Avez-vous déjà un compte ?",
    "Log in" : "Se connecter",
    "Error while verifying uploaded file" : "Erreur lors de la vérification du fichier téléversé",
    "Uploaded file is verified" : "Le fichier téléversé est vérifié",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Le format du contenu est constitué de valeurs séparées par des virgules (CSV):<br/>- La ligne d'en-tête est obligatoire et doit correspondre à <samp>\"name\",\"email\"</samp> ou juste <samp>\"email\"</samp><br/>- Une entrée par ligne (ex : <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Les participants ont été ajoutés avec succès",
    "Error while adding participants" : "Erreur lors de l'ajout des participants",
    "Import a file" : "Importer un fichier",
    "Browse" : "Parcourir",
    "Verifying uploaded file …" : "Vérification du fichier téléversé...",
    "This might take a moment" : "Cela peut prendre un moment",
    "Send invitations" : "Envoyer les invitations",
    "_%n invalid email_::_%n invalid emails_" : ["%n adresse e-mail invalide","%n adresses e-mail invalides","%n adresses e-mail invalides"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n adresse e-mail est déjà importée ou en doublon","%n adresses e-mail sont déjà importées ou en doublon","%n adresses e-mail sont déjà importées ou en doublon"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n invitation peut être envoyée","%ninvitations peuvent être envoyées","%n invitations peuvent être envoyées"],
    "An error occurred while calling a phone number" : "Une erreur est survenue en appelant un numéro de téléphone",
    "Phone number could not be called: {error}" : "Le numéro de téléphone n'a pas pu être appelé : {error}",
    "Phone number could not be called" : "Le numéro de téléphone n'a pas pu être appelé",
    "Search participants or phone numbers" : "Rechercher des participants ou des numéros de téléphone",
    "Creating the conversation …" : "Création de la conversation...",
    "Mark as read" : "Marquer comme lu",
    "Mark as unread" : "Marquer comme non lu",
    "Remove from favorites" : "Retirer des favoris",
    "Add to favorites" : "Ajouter aux favoris",
    "Unarchive conversation" : "Désarchiver la conversation",
    "Ignore \"Do not disturb\"" : "Ignorer le mode \"Ne pas déranger\"",
    "You need to promote a new moderator before you can leave the conversation." : "Vous devez désigner un nouveau modérateur avant de quitter la conversation.",
    "Conversation actions" : "Actions de la conversation",
    "Notify about calls" : "Notifier lors des appels",
    "Hide message text" : "Cacher le contenu du message",
    "Pending invitations" : "Invitations en attente",
    "From {user} at {remoteServer}" : "De {user} sur {remoteServer}",
    "Decline invitation" : "Décliner l'invitation",
    "Accept invitation" : "Accepter l'invitation",
    "No pending invitations" : "Aucune invitation en attente",
    "Home" : "Accueil",
    "Unread" : "Non lu",
    "Mentions" : "Mentions",
    "Meetings" : "Réunions",
    "Alphabetically" : "Ordre alphabétique",
    "No followed threads" : "Aucun fil de discussion suivi",
    "No matches found" : "Aucun résultat trouvé",
    "No conversations found" : "Aucune conversation trouvée",
    "You have no archived conversations." : "Vous n'avez pas de conversations archivées.",
    "Subscribe to an existing thread or start your own." : "Abonnez-vous à un fil de discussion existant ou créez le vôtre.",
    "You have no unread mentions." : "Vous n'avez pas de mentions non lues.",
    "You have no unread messages." : "Vous n'avez pas de messages non lus.",
    "An error occurred while performing the search" : "Une erreur est survenue pendant la recherche",
    "Conversation list" : "Liste des conversations",
    "Filter conversations by" : "Filtrer les conversations par",
    "Unread messages" : "Messages non lus",
    "Meeting conversations" : "Conversations de réunion",
    "Clear filters" : "Effacer les filtres",
    "New personal note" : "Nouvelle note personnelle",
    "Back to conversations" : "Retour aux conversations",
    "Archived conversations" : "Conversations archivées",
    "Threads" : "Fils de discussion",
    "Clear filter" : "Supprimer le filtre",
    "Show more threads" : "Afficher plus de fils de discussion",
    "App settings" : "Paramètres de l'application",
    "Users" : "Utilisateurs",
    "Groups" : "Groupes",
    "Teams" : "Équipes",
    "Federated users" : "Utilisateurs fédérés",
    "New private conversation" : "Nouvelle conversation privée",
    "Other sources" : "Autres sources",
    "Open conversations" : "Ouvrir des conversations",
    "No search results" : "Aucun résultat",
    "Users, groups and teams" : "Utilisateurs, groupes et équipes",
    "Users and groups" : "Utilisateurs et groupes",
    "Users and teams" : "Utilisateurs et équipes",
    "Groups and teams" : "Groupes et équipes",
    "New group conversation" : "Nouvelle conversation de groupe",
    "The meeting will start soon" : "La réunion va bientôt démarrer",
    "This meeting is scheduled for {startTime}" : "La réunion est planifiée pour {startTime}",
    "You are currently waiting in the lobby" : "Vous patientez actuellement dans la salle d'attente",
    "Enable noise suppression" : "Activer la suppression du bruit",
    "Reduce background noises for better voice quality" : "Réduisez les bruits de fond pour une meilleure qualité vocale",
    "Enable echo cancellation" : "Activer la suppression de l'écho",
    "Minimize echo effect from own surrounding" : "Minimiser l'effet d'écho provenant de l'environnement",
    "Enable auto gain control" : "Activer le contrôle automatique du gain",
    "Dynamically adjust microphone volume for consistent level" : "Ajuster dynamiquement le volume du microphone pour un niveau constant",
    "Select microphone" : "Sélectionnez un microphone",
    "No microphone available" : "Aucun microphone disponible",
    "Select speaker" : "Choisir le micro",
    "No speaker available" : "Aucun micro disponible",
    "Select camera" : "Sélectionnez une caméra",
    "No camera available" : "Aucune caméra disponible",
    "Select a device" : "Sélectionner un appareil",
    "Playing …" : "Lecture...",
    "Test speakers" : "Tester les haut-parleurs",
    "Test" : "Test",
    "Devices" : "Périphériques",
    "Backgrounds" : "Arrière-plan",
    "No audio" : "Pas de son",
    "No camera" : "Pas de caméra",
    "Display video as you will see it (mirrored)" : "Montrer la vidéo comme vous la verrez (mode miroir)",
    "Display video as others will see it" : "Montrer la vidéo comme les autres la verront",
    "Calls are not supported in your browser" : "Les appels téléphoniques ne sont pas pris en charge par votre navigateur web",
    "Access to microphone is only possible with HTTPS" : "L'accès au microphone est seulement possible en HTTPS",
    "Access to microphone was denied" : "L'accès au microphone a été refusé",
    "Error while accessing microphone" : "Erreur d'accès au microphone",
    "Access to camera is only possible with HTTPS" : "L'accès à la caméra est seulement possible en HTTPS",
    "The call is being recorded." : "L'appel est en cours d'enregistrement.",
    "The call might be recorded." : "L'appel peut être enregistré.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "L'enregistrement peut inclure votre voix, la vidéo de votre caméra et le partage d'écran. Votre consentement est requis avant de rejoindre l'appel.",
    "Give consent to the recording of this call" : "Consentir à l'enregistrement de cet appel",
    "Show more info" : "Afficher plus d'informations",
    "Audio is not available" : "L'audio n'est pas disponible",
    "Video is not available" : "La vidéo n'est pas disponible",
    "Start recording immediately with the call" : "Lancer l'enregistrement en même temps que l'appel",
    "Notify all participants about this call" : "Notifier tous les participants de cet appel",
    "Apply settings" : "Appliquer les paramètres",
    "Select virtual office background" : "Sélectionnez l'arrière-plan virtuel \"bureau\"",
    "Select virtual home background" : "Sélectionnez l'arrière-plan virtuel \"maison\"",
    "Select virtual abstract background" : "Sélectionnez l'arrière-plan virtuel \"abstrait\"",
    "Select virtual beach background" : "Sélectionnez l'arrière-plan virtuel \"plage\"",
    "Select virtual park background" : "Sélectionnez l'arrière-plan virtuel \"parc\"",
    "Select virtual theater background" : "Sélectionnez l'arrière-plan virtuel \"cinéma\"",
    "Select virtual library background" : "Sélectionnez l'arrière-plan virtuel \"bibliothèque\"",
    "Select virtual space station background" : "Sélectionnez l'arrière-plan virtuel \"station spatiale\"",
    "Error while uploading the file" : "Erreur pendant le téléversement du fichier",
    "Select a file" : "Sélectionner un fichier",
    "Invalid path selected" : "Chemin sélectionné non valide",
    "Select virtual background from file {fileName}" : "Sélectionnez l'arrière-plan virtuel depuis le fichier {fileName}",
    "Blur" : "Flou",
    "Upload" : "Téléverser",
    "Files" : "Fichiers",
    "(editing)" : "(édition)",
    "(edited)" : "(modifié)",
    "The message has expired or has been deleted" : "Le message a expiré ou a été supprimé",
    "Cancel quote" : "Annuler la citation",
    "24 hours" : "24 heures",
    "7 days" : "7 jours",
    "30 days" : "30 jours",
    "Until unpin" : "Jusqu'au désépinglage",
    "Clear reminder – {timeLocale}" : "Effacer le rappel – {timeLocale}",
    "Edited by {actor}" : "Modifié par {actor}",
    "Pinned by you" : "Épinglé par vous",
    "Pinned by {actor}" : "Épinglé par {actor}",
    "Until {absoluteDate}" : "Jusqu'au {absoluteDate}",
    "Message text copied to clipboard" : "Texte du message copié dans le presse-papier",
    "Message text could not be copied" : "Le texte du message n'a pas pu être copié",
    "Message forwarded to \"Note to self\"" : "Message transféré dans les « Notes à soi-même »",
    "Error while forwarding message to \"Note to self\"" : "Erreur pendant le transfert vers les « Notes à soi-même »",
    "A reminder was successfully removed" : "Un rappel a été supprimé avec succès",
    "Error occurred when removing a reminder" : "Une erreur est survenue à la suppression d'un rappel",
    "A reminder was successfully set at {datetime}" : "Un rappel a été placé avec succès le {datetime}",
    "Error occurred when creating a reminder" : "Une erreur est survenue à la création du rappel",
    "Add a reaction to this message" : "Ajouter une réaction à ce message",
    "Reply" : "Répondre",
    "More actions" : "Plus d'actions",
    "Set reminder" : "Définir un rappel",
    "Pin message" : "Épingler le message",
    "Unpin message" : "Désépingler le message",
    "Reply privately" : "Répondre en privé",
    "Edit message" : "Modifier le message",
    "Copy message" : "Copier le message",
    "Copy message link" : "Copier le lien du message",
    "Go to file" : "Aller au fichier",
    "Download file" : "Télécharger le fichier",
    "Go to thread" : "Aller au fil de discussion",
    "Edit thread details" : "Modifier les détails du fil de discussion",
    "Forward message" : "Transférer le message",
    "Translate" : "Traduire",
    "Set custom reminder" : "Configurer un rappel spécifique",
    "Keep pinned for" : "Garder épinglé pendant",
    "Set custom period" : "Choisir une période spécifique",
    "Close reactions menu" : "Fermer le menu des réactions",
    "React with {emoji}" : "Réagir avec {emoji}",
    "React with another emoji" : "Réagir avec un autre emoji",
    "Choose a conversation to forward the selected message." : "Choisissez une conversation où transférer le message sélectionné.",
    "Error while forwarding message" : "Erreur lors du transfert du message",
    "The message has been forwarded to {selectedConversationName}" : "Le message a été transféré sur {selectedConversationName}",
    "Dismiss" : "Rejeter",
    "Go to conversation" : "Aller à la conversation",
    "Detect language" : "Détecter la langue",
    "The message could not be translated" : "Le message n'a pas pu être traduit",
    "Translation copied to clipboard" : "Traduction copiée dans le presse-papier",
    "Translation could not be copied" : "La traduction n'a pas pu être copiée",
    "Translate message" : "Traduire le message",
    "Source language to translate from" : "Langue source pour la traduction",
    "Translate from" : "Traduire depuis",
    "Target language to translate into" : "Langue cible pour la traduction",
    "Translate to" : "Traduire vers",
    "Translating" : "Traduction",
    "Copy translated text" : "Copier le texte traduit",
    "Error when scheduling the message" : "Erreur lors de la planification du message",
    "Reschedule" : "Reprogrammer",
    "Send now" : "Envoyer immédiatement",
    "Choose a time" : "Choisir un horaire",
    "Send at custom time" : "Envoyer à un horaire spécifique",
    "Will be sent without notification" : "Sera envoyé sans notification",
    "Message read by everyone who shares their reading status" : "Message lu par tous ceux qui partagent leur statut de lecture",
    "Message sent" : "Message envoyé",
    "Sent without notification" : "Envoyé sans notification",
    "Deleting message" : "Suppression d'un message",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Le message a été supprimé, mais un robot ou Matterbridge est configuré et le message a pu être déjà distribué à d'autres services",
    "Message deleted successfully" : "Message supprimé",
    "Message could not be deleted because it is too old" : "Ce message ne peut pas être supprimé car il est trop ancien",
    "Only normal chat messages can be deleted" : "Seuls les messages instantanés standards peuvent être supprimés",
    "An error occurred while deleting the message" : "Une erreur est survenue pendant la suppression du message",
    "Pinned" : "Épinglé",
    "Your browser does not support playing audio files" : "Votre navigateur ne prend pas en charge la lecture de fichiers audio",
    "Contact" : "Contact",
    "{stack} in {board}" : "{stack} dans {board}",
    "Deck Card" : "Carte Deck",
    "Remove {fileName}" : "Supprimer {fileName}",
    "Open this location in OpenStreetMap" : "Ouvrir ce lieu sur OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n réponse","%n réponses","%n réponses"],
    "Sending message" : "Envoi du message",
    "Failed to send the message. Click to try again" : "Échec de l'envoi du message. Cliquez pour réessayer",
    "Not enough free space to upload file" : "Espace libre insuffisant pour téléverser le fichier",
    "You cannot send messages to this conversation at the moment" : "Vous ne pouvez pas envoyer de message dans cette conversation actuellement",
    "Could not update the message" : "Impossible de mettre à jour le message",
    "Reply to thread \"{threadTitle}\"" : "Répondre dans le fil de discussion \"{threadTitle}\"",
    "You voted" : "Vous avez voté",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Brouillon de sondage • %n option","Brouillon de sondage • %n options","Brouillon de sondage • %n options"],
    "_%n vote_::_%n votes_" : ["%n vote","%n votes","%n votes"],
    "Edit poll draft" : "Éditer le brouillon du sondage",
    "Delete poll draft" : "Supprimer le brouillon du sondage",
    "Open poll" : "Sondage ouvert",
    "See results" : "Voir les résultats",
    "Reactions" : "Réactions",
    "No permission to post reactions in this conversation" : "Interdiction de poster des réactions dans cette conversation",
    "and {participant}" : "et {participant}",
    "_and %n other participant_::_and %n other participants_" : ["et %n autre participant ","et %n autres participants","et %n autres participants"],
    "Show all reactions" : "Afficher toutes les réactions",
    "Add more reactions" : "Ajouter plus de réactions",
    "Show or collapse system messages" : "Afficher ou cacher les messages système",
    "No messages" : "Aucun message",
    "All messages have expired or have been deleted." : "Tous les messages ont expiré ou ont été supprimés.",
    "{author} (pinned by you)" : "{author} (épinglé par vous)",
    "{author} (pinned by {actor})" : "{author} (épinglé par {actor})",
    "Unpin" : "Détacher",
    "Cancel search" : "Annuler la recherche",
    "Add a phone number" : "Ajouter un numéro de téléphone",
    "Error: A password is required to create the conversation." : "Erreur : Un mot de passe est requis pour créer la conversation.",
    "All set, the conversation \"{conversationName}\" was created." : "Tout est prêt, la conversation « {conversationName} » a été créée.",
    "Create a new group conversation" : "Créer une nouvelle conversation de groupe",
    "Add participants" : "Ajouter des participants",
    "Maximum length exceeded ({maxlength} characters)" : "Longueur maximale dépassée ({maxlength} caractères)",
    "Conversation visibility" : "Visibilité de la conversation",
    "Allow guests to join via link" : "Permettre aux invités de rejoindre via un lien",
    "Enter password" : "Saisir le mot de passe",
    "This conversation has been locked" : "Cette conversation a été verrouillée",
    "No permission to post messages in this conversation" : "Interdit de publier un message dans cette conversation",
    "Joining conversation …" : "Rejoindre la conversation…",
    "Write a message without notification" : "Écrire un message sans notification",
    "Create a thread silently" : "Créer silencieusement un fil de discussion",
    "Create a thread" : "Créer un fil de discussion",
    "Send message silently" : "Envoyer le message silencieusement",
    "Send message" : "Envoyer un message",
    "Send without notification" : "Envoyer sans notification",
    "The participant will not be notified about new messages" : "Les participants ne seront pas notifiés de nouveaux messages",
    "Participants will not be notified about new messages" : "Les participants seront pas notifiés de nouveaux messages",
    "Message will be sent {datetimeString}" : "Le message sera envoyé le {datetimeString}",
    "Thread title is required" : "Un titre de fil de discussion est obligatoire",
    "Message text is required" : "Le texte du message est obligatoire",
    "The message could not be edited" : "Le message n'a pas pu être modifié",
    "File to share" : "Fichier à partager",
    "File upload is not available in this conversation" : "Le téléversement de fichier n'est pas disponible dans cette conversation",
    "Message was successfully scheduled" : "Message programmé avec succès",
    "Add emoji" : "Ajouter un emoji",
    "Adding a mention will only notify users who did not read the message." : "Ajouter une mention notifiera les utilisateurs qui n'ont pas lu le message.",
    "Thread title" : "Titre du fil de discussion",
    "Send later" : "Envoyer ultérieurement",
    "Show scheduled messages" : "Montrer les messages programmés",
    "Cancel editing" : "Annuler la modification",
    "Schedule message" : "Programmer le message",
    "{user} is out of office and might not respond." : "{user} est absent et pourrait ne pas répondre.",
    "Absence period: {startDate} - {endDate}" : "Période d'absence du {startDate} au {endDate}",
    "Replacement:" : "Remplaçant : ",
    "Share from {nextcloud}" : "Partager depuis {nextcloud}",
    "Share from Files" : "Partager depuis Fichiers",
    "Share files to the conversation" : "Partager des fichiers à cette conversation",
    "Upload from device" : "Téléverser depuis l'appareil",
    "Create new poll" : "Créer un nouveau sondage",
    "Smart picker" : "Sélecteur intelligent",
    "Record voice message" : "Enregistrer un message vocal",
    "End recording and send" : "Terminer l'enregistrement et l'envoyer",
    "Dismiss recording" : "Annuler l'enregistrement",
    "Access to the microphone was denied" : "L'accès au microphone n'est pas autorisé",
    "Microphone either not available or disabled in settings" : "Le microphone n'est pas disponible ou il est désactivé dans les paramètres",
    "Error while recording audio" : "Erreur pendant l'enregistrement de l'audio",
    "Generating summary of unread messages …" : "Génération du résumé des messages non lus...",
    "Summary is AI generated and might contain mistakes" : "Le résumé est généré par une intelligence artificielle et peut contenir des erreurs",
    "Error occurred during a summary generation" : "Une erreur est survenue pendant la génération du résumé",
    "New file" : "Nouveau fichier",
    "Blank" : "Vide",
    "Error while creating file" : "Erreur à la création du fichier",
    "Create and share a new file" : "Créer et partager un nouveau fichier",
    "Name of the new file" : "Nom du nouveau fichier",
    "Create file" : "Créer un fichier",
    "Someone is typing …" : "Quelqu'un est en train d'écrire...",
    "{user1} is typing …" : "{user1} est en train d'écrire...",
    "{user1} and {user2} are typing …" : "{user1} et {user2} sont en train d'écrire...",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} et {user3} sont en train d'écrire...",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} et %n autre participant écrivent …","{user1}, {user2}, {user3} et %n autres participants écrivent …","{user1}, {user2}, {user3} et %n autres participants sont en train d'écrire..."],
    "Add more files" : "Ajouter d'autres fichiers",
    "Send" : "Envoyer",
    "In this conversation <strong>{user}</strong> can:" : "Dans cette conversation <strong>{user}</strong> peut :",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Modifier les permissions par défaut pour les participants de la conversation  <strong>{conversationName}</strong>",
    "Start a call" : "Lancer un appel",
    "Skip the lobby" : "Ignorer la salle d'attente",
    "Can post messages" : "Les messages ne peuvent pas être envoyés",
    "Can post messages and reactions" : "Autoriser à poster des messages et à envoyer des réactions",
    "Can add reactions" : "Les réactions ne peuvent être ajoutés",
    "Enable the microphone" : "Activer le microphone",
    "Enable the camera" : "Activer la caméra",
    "Share the screen" : "Partager l'écran",
    "Update permissions" : "Mettre à jour les permissions",
    "Updating permissions" : "Mise à jour des permissions",
    "No poll drafts" : "Aucun brouillon de sondage",
    "There is no poll drafts yet saved for this conversation" : "Il n'y a pas encore de brouillon de sondage enregistré pour cette conversation",
    "Create poll in {name}" : "Créer un sondage dans {name}",
    "Create poll" : "Créer le sondage",
    "Error while importing poll" : "Erreur lors de l'import du sondage",
    "Question" : "Question",
    "Ask a question" : "Poser une question",
    "Import draft from file" : "Importer un brouillon à partir du fichier",
    "Answers" : "Réponses",
    "Answer {option}" : "Réponse {option}",
    "Delete poll option" : "Supprimer l'option de sondage",
    "Add answer" : "Ajouter une réponse",
    "Settings" : "Paramètres",
    "Anonymous poll" : "Sondage anonyme",
    "Multiple answers" : "Réponses multiples",
    "Save as draft" : "Enregistrer comme brouillon",
    "Export draft to file" : "Exporter le brouillon vers un fichier",
    "You voted for this option" : "Vous avez voté pour cette option",
    "End poll" : "Mettre fin au sondage",
    "Change your vote" : "Changer votre vote",
    "Results" : "Résultats",
    "Voted participants" : "Participants qui ont voté",
    "Send a message to \"{roomName}\"" : "Envoyer un message à la salle \"{roomName}\"",
    "Hide list of participants" : "Masquer la liste des participants",
    "Show list of participants" : "Montrer la liste des participants",
    "Assistance requested in {roomName}" : "Assistance demandée dans {roomName}",
    "The message was sent to \"{roomName}\"" : "Le message a été posté dans \"{roomName}\"",
    "Dismiss request for assistance" : "Ignorer la demande d'assistance",
    "Send message to room" : "Envoyer un message à la salle",
    "Back to main room" : "Retour à la salle principale",
    "Back to your room" : "Retour à votre salle",
    "Message all rooms" : "Envoyer un message à toutes les salles",
    "Start session" : "Démarrer une session",
    "Start a call before you start a breakout room session" : "Lancer un appel avant de démarrer une salle de sous-groupe",
    "Stop session" : "Terminer une session",
    "The message was sent to all breakout rooms" : "Le message a été envoyé à toutes les salles de sous-groupes",
    "Send a message to all breakout rooms" : "Envoyer un message à toutes les salles de sous-groupes",
    "Breakout rooms are not started" : "Les salles de sous-groupes ne sont pas démarrées",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Les appels sans serveur haute performance peuvent entraîner des problèmes de connectivité et une charge importante sur les appareils. {linkstart}En savoir plus {linkend}",
    "Talk setup incomplete" : "Configuration de Talk incomplète",
    "Disable lobby" : "Désactiver la salle d'attente",
    "Settings for participant \"{user}\"" : "Paramètres du participant \"{user}\"",
    "Participant \"{user}\"" : "Participant \"{user}\"",
    "moderator" : "modérateur",
    "bot" : "robot",
    "guest" : "invité",
    "Ringing …" : "Ça sonne...",
    "Call rejected" : "Appel rejeté",
    "{time} talking …" : "{time} est en train de parler…",
    "{time} talking time" : "{time} de temps de parole",
    "Raised their hand" : "A levé la main",
    "Joined with video" : "A rejoint avec vidéo",
    "Joined via phone" : "Connecté par téléphone",
    "Joined with audio" : "A rejoint avec audio",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Le texte doit être inférieur ou égal à {maxLength} caractères. Votre texte actuel comporte {charactersCount} caractères.",
    "Remove group and members" : "Retirer le groupe et ses membres",
    "Remove team and members" : "Supprimer l'équipe et ses membres",
    "Remove participant" : "Retirer le participant",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Voulez-vous vraiment retirer le groupe  \"{displayName}\" et ses membres de cette conversation ?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Voulez-vous vraiment retirer l'équipe \"{displayName}\" et ses membres de cette conversation ?",
    "Do you really want to remove {displayName} from this conversation?" : "Voulez-vous vraiment retirer {displayName} de cette conversation ?",
    "Notification was sent to {displayName}" : "La notification a été envoyée à {displayName}",
    "Could not send notification to {displayName}" : "Impossible d'envoyer la notification à {displayName}",
    "Permissions granted to {displayName}" : "Permissions accordées à {displayName}",
    "Could not modify permissions for {displayName}" : "Impossible de modifier les permissions pour {displayName}",
    "Permissions removed for {displayName}" : "Permissions retirées pour {displayName}",
    "Permissions set to default for {displayName}" : "Permissions réinitialisées pour {displayName}",
    "Phone number could not be hung up" : "Le numéro de téléphone n'a pas pu être raccroché",
    "Phone number could not be put on hold" : "Impossible de mettre en attente le numéro de téléphone",
    "Phone number could not be muted" : "Impossible de mettre en sourdine le numéro de téléphone",
    "Phone number could not be unmuted" : "Impossible de réactiver le numéro de téléphone",
    "DTMF message could not be sent" : "Impossible d’envoyer le message DTMF",
    "Phone number copied to clipboard" : "Numéro de téléphone copié dans le presse-papier",
    "Phone number could not be copied" : "Le numéro de téléphone n’a pas pu être copié dans le presse-papiers",
    "in the lobby" : "dans la salle d'attente",
    "Dial out phone" : "Composer un numéro de téléphone",
    "Hang up phone" : "Raccrocher le téléphone",
    "Move back to lobby" : "Retourner à la salle d'attente",
    "Move to conversation" : "Déplacer dans la conversation",
    "Dial-in PIN" : "Code PIN",
    "Demote from moderator" : "Retirer le statut de modérateur",
    "Promote to moderator" : "Promouvoir comme modérateur",
    "Resend invitation" : "Renvoyer l'invitation",
    "Send call notification" : "Envoyer une notification d'appel",
    "Dial out phone number" : "Composer un numéro de téléphone",
    "Resume call for phone number" : "Reprendre l'appel pour le numéro de téléphone",
    "Put phone number on hold" : "Mettre le numéro de téléphone en attente",
    "Unmute phone number" : "Activer le son du numéro de téléphone",
    "Mute phone number" : "Masquer le numéro de téléphone",
    "Copy phone number" : "Copier le numéro de téléphone",
    "Reset custom permissions" : "Réinitialiser les permissions personnalisées",
    "Grant all permissions" : "Accorder toutes les permissions",
    "Remove all permissions" : "Retirer toutes les permissions",
    "Also ban from this conversation" : "Bannir aussi de cette conversation",
    "Internal note (reason to ban)" : "Note interne (raison du bannissement)",
    "Remove" : "Retirer",
    "Permissions modified for {displayName}" : "Permissions modifiées pour {displayName}",
    "Add users, groups or teams" : "Ajouter des utilisateurs, des groupes ou des équipes",
    "Add users or groups" : "Ajouter des utilisateurs ou des groupes",
    "Add users or teams" : "Ajouter des utilisateurs ou des équipes",
    "Add users" : "Ajouter des utilisateurs",
    "Add groups or teams" : "Ajouter des groupes ou des équipes",
    "Add groups" : "Ajouter des groupes",
    "Add teams" : "Ajouter des équipes",
    "Add other sources" : "Ajouter d'autres sources",
    "Add emails" : "Ajouter des adresses e-mails",
    "Integrations" : "Intégrations",
    "Add federated users" : "Ajouter des utilisateurs fédérés",
    "Searching …" : "Recherche …",
    "Search for more users" : "Rechercher d'autres utilisateurs",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Vous pouvez rechercher ou ajouter des participants par nom, e-mail ou ID de cloud fédéré.",
    "Search or add participants" : "Rechercher ou ajouter des participants",
    "Invitation was sent to {actorId}" : "L'invitation a été envoyée à {actorId}",
    "An error occurred while adding the participants" : "Une erreur est survenue lors de l’ajout de participants",
    "A new group conversation with selected participant will be created" : "Une nouvelle conversation de groupe avec les participants sélectionnés va être créée",
    "Participants" : "Participants",
    "Pinned by a deleted user" : "Épinglé par un utilisateur supprimé",
    "Participants ({count})" : "Participants ({count})",
    "Open chat" : "Ouvrir la discussion instantanée",
    "You have new unread messages in the chat." : "Vous avez des messages non lus dans la discussion.",
    "You have been mentioned in the chat." : "Vous avez été mentionné·e dans la discussion.",
    "Search messages" : "Rechercher des messages",
    "Chat" : "Discussion",
    "Details" : "Details",
    "Shared items" : "Éléments partagés",
    "Search in {name}" : "Rechercher dans {name}",
    "Threads in {name}" : "Fils de discussion dans {name}",
    "{actor} in {conversation}" : "{actor} dans {conversation}",
    "Search messages …" : "Recherche de messages …",
    "Search options" : "Options de recherche",
    "From User" : "De l'utilisateur",
    "Since" : "Depuis",
    "Until" : "Jusqu'au",
    "No results found" : "Aucun résultat",
    "Load more results" : "Charger plus de résultats",
    "Recent threads" : "Fils de discussion récents",
    "Projects" : "Projets",
    "No shared items" : "Aucun élément partagé",
    "Thread notifications" : "Notifications de fil de discussion",
    "Thread actions" : "Actions du fil de discussion",
    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
    "Link to a conversation" : "Relier à une conversation",
    "No open conversations found" : "Aucune conversation publique n'a été trouvée",
    "Either there are no open conversations or you joined all of them." : "Soit il n'y a pas de conversations publiques, soit vous les avez toutes rejointes.",
    "Check spelling or use complete words." : "Vérifier l'orthographe ou utiliser les mots complets.",
    "Search conversations or users" : "Rechercher des conversations ou des utilisateurs",
    "Select conversation" : "Sélectionnez la conversation",
    "Number length is not valid" : "La longueur du numéro est invalide",
    "Region code is not valid" : "L'indicatif téléphonique est invalide",
    "Number length is too short" : "La longueur du numéro est trop courte",
    "Number length is too long" : "La longueur du numéro est trop longue",
    "Number is not valid" : "Le numéro est invalide",
    "Phone numbers" : "Numéros de téléphone",
    "Display name: {name}" : "Nom affiché : {name}",
    "Edit display name" : "Modifier le nom d'affichage",
    "Display name (required)" : "Display name (obligatoire)",
    "Save name" : "Sauvegarder le nom",
    "I picked message bubbles" : "J'ai choisi des bulles de message",
    "Error while setting personal setting" : "Erreur lors de la prise en compte de vos paramètres personnels",
    "Error while saving sounds setting" : "Erreur lors de l'enregistrement des paramètres audio",
    "Compact conversations list" : "Liste compacte des conversations",
    "Chat appearance" : "Apparence de la discussion",
    "Messages list" : "Liste de messages",
    "Message bubbles" : "Bulles de message",
    "Play sounds when participants join or leave a call" : "Jouer un son lorsque des participants rejoignent ou quittent un appel",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Actuellement non disponible sur iPhone et iPad en raison de restrictions techniques par le fabricant",
    "Notification settings" : "Paramètres de notification",
    "Sounds for chat and call notifications" : "Sons pour les notifications d'appel et de conversation",
    "Invalid language ({languageId})" : "Langue invalide ({languageId})",
    "Default language" : "Langue par défaut",
    "Default language ({languageName})" : "Langue par défaut ({languageName})",
    "Error when trying to load the available live translation languages" : "Erreur lors du chargement des langues disponibles pour la traduction en direct",
    "Error when trying to set live translation language" : "Erreur lors de la tentative de configuration de la langue de traduction en direct",
    "Set language used to show the transcriptions" : "Définir la langue utilisée pour afficher les transcriptions",
    "Select location for attachments" : "Sélectionnez l'emplacement des pièces jointes",
    "Error while setting attachment folder" : "Erreur lors de la définition du dossier pour la pièce jointe",
    "Error while setting read status privacy" : "Erreur lors de la définition de la confidentialité de l'état de lecture",
    "Error while setting typing status privacy" : "Erreur au paramétrage du partage du statut de saisie",
    "Error while setting default media state" : "Erreur lors de la définition de l'état par défaut des médias",
    "Turn camera and microphone off by default" : "Désactiver par défaut la caméra et le microphone",
    "Blur camera background by default" : "Flouter l'arrière-plan de la caméra par défaut",
    "Skip device preview before joining a call" : "Ignorer l'aperçu du périphérique avant de rejoindre un appel",
    "Appearance & Sounds" : "Apparence et sons",
    "Privacy" : "Confidentialité",
    "Send read receipts" : "Envoyer des accusés de lecture",
    "When off, all read statuses will be hidden" : "Si désactivé, tous les statuts de lecture seront cachés",
    "Share typing status" : "Partager le statut de frappe",
    "When off, all typing indicators will be hidden" : "Si désactivé, tous les statuts de frappe seront cachés",
    "Attachments folder" : "Dossier des pièces jointes",
    "Toggle full screen" : "Basculer en mode plein écran",
    "Return to Home screen" : "Retourner à l'écran d'accueil",
    "Search" : "Rechercher",
    "Shortcuts while in a chat" : "Raccourci pendant la conversation",
    "Focus the chat input" : "Maintenir le focus sur la zone de saisie",
    "Unfocus the chat input to use shortcuts" : "Libérer le focus sur la zone de saisie pour utiliser les raccourcis",
    "Edit your last message" : "Modifier votre dernier message",
    "Shortcuts while in a call" : "Raccourcis pendant un appel",
    "Camera on and off" : "Activer ou désactiver la webcam",
    "Microphone on and off" : "Activer ou désactiver le microphone",
    "Raise or lower hand" : "Lever ou baisser la main",
    "Push to talk or push to mute" : "Appuyer pour parler ou pour mettre en silence",
    "Zoom-in / zoom-out a screen share" : "Zoomer / Dézoomer un partage d'écran",
    "Mouse wheel" : "Molette de souris",
    "Start call silently" : "Lancer silencieusement l'appel",
    "Start call" : "Lancer l'appel",
    "End call" : "Terminer l'appel",
    "This call has just ended" : "Cet appel vient de se terminer",
    "You will be able to join the call only after a moderator starts it." : "Vous pourrez rejoindre l'appel seulement après son lancement par un modérateur.",
    "End call for everyone" : "Mettre fin à l'appel pour tout le monde",
    "Starting the recording" : "Lancement de l'enregistrement",
    "Recording" : "Enregistrement",
    "The call has been running for one hour." : "L'appel a duré une heure.",
    "Cancel recording start" : "Annuler le lancement de l'enregistrement",
    "Stop recording" : "Arrêter l'enregistrement",
    "Send a reaction" : "Envoyer une réaction",
    "React with {reaction}" : "Réagir avec {reaction}",
    "All tasks done!" : "Toutes les tâches sont terminées !",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} tâche sur %n","{done} tâches sur %n","{done} tâches sur %n"],
    "Add participants to this call" : "Ajouter des participants à cet appel",
    "_%n participant in call_::_%n participants in call_" : ["%n participant dans cet appel","%n participants dans cet appel","%n participants dans cet appel"],
    "Scheduled messages" : "Messages programmés",
    "You are not allowed to enable screensharing" : "Vous n'êtes pas autorisé à partager l'écran",
    "No screensharing" : "Aucun partage d'écran",
    "Screensharing options" : "Options du partage d'écran",
    "Enable screensharing" : "Activer le partage d'écran",
    "Bad sent video and screen quality." : "Mauvaise qualité de la vidéo et du partage d'écran.",
    "Bad sent screen quality." : "Mauvaise qualité du partage d'écran.",
    "Bad sent video quality." : "Mauvaise qualité de la vidéo.",
    "Bad sent audio, video and screen quality." : "Mauvaise qualité de l'audio, de la vidéo et du partage d'écran.",
    "Bad sent audio and screen quality." : "Mauvaise qualité de l'audio et du partage d'écran.",
    "Bad sent audio and video quality." : "Mauvaise qualité de l'audio et de la vidéo.",
    "Bad sent audio quality." : "Mauvaise qualité de l'audio.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient ne pas voir votre écran. Pour améliorer la situation, essayez de désactiver le flou d'arrière-plan ou votre vidéo pendant le partage d'écran.",
    "Disable background blur" : "Désactiver le flou d'arrière-plan",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient ne pas voir votre écran. Pour améliorer la situation, essayez de désactiver le flou d'arrière-plan ou votre vidéo pendant le partage d'écran.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient ne pas voir votre écran.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient avoir du mal à vous voir.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient avoir du mal à vous comprendre et à vous voir Pour améliorer la situation, essayez de désactiver le flou d'arrière-plan ou votre vidéo pendant le partage d'écran.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient avoir du mal à vous comprendre et à vous voir. Pour améliorer la situation, essayez de désactiver votre vidéo pendant le partage d'écran.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient avoir du mal à vous comprendre et à voir votre écran. Pour améliorer la situation, essayez de désactiver votre partage d'écran.",
    "Disable screenshare" : "Désactiver le partage d'écran",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient avoir du mal à vous comprendre et à vous voir. Pour améliorer la situation, essayez de désactiver le flou d'arrière-plan ou votre vidéo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants pourraient avoir du mal à vous comprendre et à vous voir. Pour améliorer la situation, essayez de désactiver votre vidéo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Votre connexion internet ou votre ordinateur sont surchargés et les autres participants peuvent avoir du mal à vous comprendre.",
    "Screen sharing is not supported by your browser." : "Le partage d'écran n'est pas pris en charge par votre navigateur.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Le partage d'écran nécessite que la page soit chargée en HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Le partage d’écran nécessite que la page soit chargée en HTTPS.",
    "An error occurred while starting screensharing." : "Une erreur est survenue lors du démarrage du partage d’écran.",
    "Select virtual background" : "Sélectionner un arrière-plan virtuel",
    "Show your screen" : "Afficher votre écran",
    "Stop screensharing" : "Terminer le partage d'écran",
    "Mute others" : "Mettre en sourdine les autres",
    "Start recording" : "Lancer l'enregistrement",
    "Set up breakout rooms" : "Configurer les salles de sous-groupes",
    "Download attendance list" : "Télécharger la liste de présence",
    "Open Calendar" : "Ouvrir Agenda",
    "Remove participant {name}" : "Retirer le participant nommé {name}",
    "Would you like to delete this conversation?" : "Souhaitez-vous supprimer cette conversation ?",
    "Are you sure you want to delete this conversation?" : "Êtes-vous sûr de vouloir supprimer cette conversation ?",
    "Delete now" : "Supprimer maintenant",
    "Keep" : "Conserver",
    "Open dialpad" : "Ouvrir le clavier de composition du numéro",
    "Select a region" : "Sélectionner une région",
    "Local time: {time}" : "Heure locale : {time}",
    "Scheduled {datetime}" : "Programmé {datetime}",
    "Scheduled for {datetime}" : "Programmé pour {datetime}",
    "Search …" : "Recherche…",
    "Message without mention" : "Message sans mention",
    "Mention myself" : "Me mentionner",
    "Mention everyone" : "Mentionner tout le monde",
    "Select a conversation" : "Sélectionner une conversation",
    "Select a mode" : "Sélectionner un mode",
    "You do not have permissions to access this conversation." : "Vous n'avez pas le droit d'accéder à cette conversation.",
    "Join a different conversation or start a new one." : "Rejoindre une conversation ou en commencer une nouvelle.",
    "The conversation does not exist" : "La conversation n'existe pas",
    "Join a conversation or start a new one!" : "Rejoignez une conversation ou démarrez-en une nouvelle",
    "Duplicate session" : "Session en double",
    "Creating and joining a conversation with \"{userid}\"" : "Création et intégration d’une conversation avec « {userid} »",
    "Join a conversation or start a new one" : "Rejoignez une conversation ou démarrez-en une nouvelle",
    "Error while joining the conversation" : "Erreur lors de l’intégration à la conversation",
    "Another user" : "Autre utilisateur",
    "Nextcloud URL" : "URL Nextcloud",
    "Nextcloud user" : "Utilisateur Nextcloud",
    "User password" : "Mot de passe utilisateur",
    "Talk conversation" : "Conversation Talk",
    "Skip TLS verification" : "Ignorer la vérification TLS",
    "Matrix server URL" : "URL du serveur Matrix",
    "User" : "Utilisateur",
    "Matrix channel" : "Canal Matrix",
    "Mattermost server URL" : "URL du serveur Mattermost",
    "Mattermost user" : "Utilisateur Mattermost",
    "Team name" : "Nom d'équipe",
    "Channel name" : "Nom du canal",
    "Rocket.Chat server URL" : "URL du serveur Rocket.Chat",
    "User name or email address" : "Identifiant ou adresse e-mail",
    "Rocket.Chat channel" : "Canal Rocket.Chat",
    "Zulip server URL" : "URL du serveur Zulip",
    "Bot user name" : "Nom d'utilisateur du bot",
    "Bot API key" : "Clé API du bot",
    "Zulip channel" : "Canal Zulip",
    "API token" : "Jeton d'API",
    "Slack channel" : "Canal Slack",
    "Server ID or name" : "Identifiant ou nom du serveur",
    "Channel ID (prefixed with \"ID:\") or name" : "Nom du canal ou ID (préfixé par \"ID:\")",
    "Channel" : "Canal",
    "Login" : "S’identifier",
    "Chat ID" : "Identifiant de la discussion",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL du serveur IRC (ex. chat.freenode.net:6667)",
    "Nickname" : "Surnom",
    "Connection password" : "Mot de passe de connexion",
    "IRC channel" : "Canal IRC",
    "Channel password" : "Mot de passe du canal",
    "NickServ nickname" : "Nom d'utilisateur NickServ",
    "NickServ password" : "Mot de passe NickServ",
    "Use TLS" : "Utiliser TLS",
    "Use SASL" : "Utiliser SASL",
    "Tenant ID" : "Identifiant Tenant",
    "Client ID" : "ID Client",
    "Team ID" : "Identifiant Team",
    "Thread ID" : "Identifiant du fil de discussion",
    "XMPP/Jabber server URL" : "URL du serveur XMPP/Jabber",
    "MUC server URL" : "URL du serveur MUC",
    "Jabber ID" : "ID Jabber",
    "Pinned messages" : "Messages épinglés",
    "Media" : "Médias",
    "Polls" : "Sondages",
    "Deck cards" : "Cartes Deck",
    "Voice messages" : "Messages vocaux",
    "Locations" : "Lieux",
    "Call recordings" : "Enregistrements des appels",
    "Audio" : "Son",
    "Show all pinned messages" : "Montrer tous les messages épinglés",
    "Show all media" : "Montrer tous les médias",
    "Show all files" : "Afficher tous les fichiers",
    "Show all polls" : "Afficher tous les sondages",
    "Show all deck cards" : "Montrer toutes les cartes Deck",
    "Show all voice messages" : "Afficher tous les messages vocaux",
    "Show all locations" : "Montrer tous les emplacements",
    "Show all call recordings" : "Afficher tous les enregistrements d'appels",
    "Show all audio" : "Montrer tous les audio",
    "Show all other" : "Montrer tous les autres",
    "Follow conversation settings" : "Utiliser les paramètres de la conversation",
    "Group" : "Groupe",
    "Team" : "Équipe",
    "You reconnected to the call" : "Vous avez rejoint l'appel à nouveau",
    "{actor} reconnected to the call" : "{actor} a rejoint l'appel à nouveau",
    "You added {user0} and {user1}" : "Vous avez ajouté {user0} et {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Vous avez ajouté {user0}, {user1} et %n autre participant","Vous avez ajouté {user0}, {user1} et %n autres participants","Vous avez ajouté {user0}, {user1} et %n autres participants"],
    "An administrator added you and {user0}" : "Un administrateur a ajouté {user0} et vous",
    "{actor} added you and {user0}" : "{actor} a ajouté {user0} et vous",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Un administrateur a ajouté {user0}, vous et %n autre participant","Un administrateur a ajouté {user0}, vous et %n autres participants","Un administrateur a ajouté {user0}, vous et %n autres participants"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} a ajouté {user0}, vous et %n autre participant","{actor} a ajouté {user0}, vous et %n autres participants","{actor} a ajouté {user0}, vous et %n autres participants"],
    "An administrator added {user0} and {user1}" : "Un administrateur a ajouté {user0} et {user1}",
    "{actor} added {user0} and {user1}" : "{actor} a ajouté {user0} et {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Un administrateur a ajouté {user0}, {user1} et %n autre participant","Un administrateur a ajouté {user0}, {user1} et %n autres participants","Un administrateur a ajouté {user0}, {user1} et %n autres participants"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} a ajouté {user0}, {user1} et  %n autre participant","{actor} a ajouté {user0}, {user1} et  %n autres participants","{actor} a ajouté {user0}, {user1} et %n autres participants"],
    "You removed {user0} and {user1}" : "Vous avez retiré {user0} et {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Vous avez retiré {user0}, {user1} et %n autre participant","Vous avez retiré {user0}, {user1} et %n autres participants","Vous avez retiré {user0}, {user1} et %n autres participants"],
    "An administrator removed you and {user0}" : "Un administrateur vous a retiré et {user0}",
    "{actor} removed you and {user0}" : "{actor}  vous a retiré et {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Un administrateur vous a retiré, {user0} et %n autre participant","Un administrateur vous a retiré, {user0} et %n autres participants","Un administrateur vous a retiré, {user0} et %n autres participants"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} vous a retiré, {user0} et %n autre participant","{actor} vous a retiré, {user0} et %n autres participants","{actor} vous a retiré, {user0} et %n autres participants"],
    "An administrator removed {user0} and {user1}" : "Un administrateur a retiré {user0} et {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} a retiré {user0} et {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Un administrateur a retiré {user0}, {user1} et %n autre participant","Un administrateur a retiré {user0}, {user1} et %n autres participants","Un administrateur a retiré {user0}, {user1} et %n autres participants"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} a retiré {user0}, {user1} et  %n autre participant","{actor} a retiré {user0}, {user1} et  %n autres participants","{actor} a retiré {user0}, {user1} et %n autres participants"],
    "You and {user0} joined the call" : "Vous et {user0}avez rejoint l'appel",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Vous, {user0} et %n autre participant avez rejoint l'appel","Vous, {user0} et %n autres participants avez rejoint l'appel","Vous, {user0} et %n autres participants avez rejoint l'appel"],
    "{user0} and {user1} joined the call" : "{user0} et {user1} ont rejoint l'appel",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} et %n autre participant ont rejoint l'appel","{user0}, {user1} et %n autres participants ont rejoint l'appel","{user0}, {user1} et %n autres participants ont rejoint l'appel"],
    "You and {user0} left the call" : "Vous et {user0} avez quitté l'appel",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["{user0}, %n autre participant et vous avez quitté l'appel","{user0}, %n autres participants et vous avez quitté l'appel","Vous, {user0}, %n autres participants avez quitté l'appel"],
    "{user0} and {user1} left the call" : "{user0} et {user1} ont quitté l'appel",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} et %n autre participant ont quitté l'appel","{user0}, {user1} et %n autres participants ont quitté l'appel","{user0}, {user1} et %n autres participants ont quitté l'appel"],
    "You promoted {user0} and {user1} to moderators" : "Vous avez promu {user0} et {user1} modérateurs",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Vous avez promu {user0}, {user1} et %n autre participant modérateurs","Vous avez promu {user0}, {user1} et %n autres participants modérateurs","Vous avez promu {user0}, {user1} et %n autres participants modérateurs"],
    "An administrator promoted you and {user0} to moderators" : "Un administrateur vous a promu modérateur ainsi que {user0}",
    "{actor} promoted you and {user0} to moderators" : "{actor} vous a promu modérateur ainsi que {user0}",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Un administrateur a promu {user0}, %n autre participant et vous modérateurs","Un administrateur a promu {user0}, %n autres participants et vous modérateurs","Un administrateur vous a promu modérateur ainsi que {user0} et %n autres participants"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} a promu {user0}, %n autre participant et vous modérateurs","{actor} a promu {user0}, %n autres participants et vous modérateurs","{actor} vous a promu modérateur ainsi que {user0} et %n autres participants"],
    "An administrator promoted {user0} and {user1} to moderators" : "Un administrateur a promu {user0} et {user1} modérateurs",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} a promu {user0} et {user1} modérateurs",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Un administrateur a promu {user0}, {user1} et %n autre participant modérateurs","Un administrateur a promu {user0}, {user1} et %n autres participants modérateurs","Un administrateur a promu {user0}, {user1} et %n autres participants modérateurs"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} a promu {user0}, {user1} et %n autre participant modérateurs","{actor} a promu {user0}, {user1} et %n autres participants modérateurs","{actor} a promu {user0}, {user1} et %n autres participants modérateurs"],
    "You demoted {user0} and {user1} from moderators" : "Vous avez retiré {user0} et {user1} de la liste des modérateurs",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Vous avez retiré {user0}, {user1} et %n autre participant de la liste des modérateurs","Vous avez retiré {user0}, {user1} et %n autres participants de la liste des modérateurs","Vous avez retiré {user0}, {user1} et %n autres participants de la liste des modérateurs"],
    "An administrator demoted you and {user0} from moderators" : "Un administrateur vous a retiré de la liste des modérateurs ainsi que {user0} ",
    "{actor} demoted you and {user0} from moderators" : "{actor} vous a retiré de la liste des modérateurs ainsi que {user0}",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Un administrateur vous a retiré la liste des modérateurs ainsi que {user0} et %n autre participant","Un administrateur vous a retiré de la liste des modérateurs ainsi que{user0} et %n autres participants","Un administrateur vous a retiré de la liste des modérateurs ainsi que{user0} et %n autres participants"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} vous a retiré de la liste des modérateurs ainsi que {user0} et %n autre participant","{actor} vous a retiré de la liste des modérateurs ainsi que {user0} et %n autres participants","{actor} vous a retiré de la liste des modérateurs ainsi que {user0} et %n autres participants"],
    "An administrator demoted {user0} and {user1} from moderators" : "Un administrateur a retiré {user0} et {user1} de la liste des modérateurs",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} a retiré {user0} et {user1} de la liste des modérateurs",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Un administrateur a retiré {user0}, {user1} et %n autre participant de la liste des modérateurs","Un administrateur a retiré {user0}, {user1} et %n autres participants de la liste des modérateurs","Un administrateur a retiré {user0}, {user1} et %n autres participants de la liste des modérateurs"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} a retiré {user0}, {user1} et %n autre participant de la liste des modérateurs","{actor} a retiré {user0}, {user1} et %n autres participants de la liste des modérateurs","{actor} a retiré {user0}, {user1} et %n autres participants de la liste des modérateurs"],
    "You:" : "Vous : ",
    "You: {lastMessage}" : "Moi : {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(modifié par vous)",
    "(edited by a deleted user)" : "(modifié par un utilisateur supprimé)",
    "(edited by {moderator})" : "(modifié par {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Vous essayez de rejoindre une conversation mais vous avez déjà une session ouverte sur une autre fenêtre ou un autre périphérique. Ce n'est pas possible pour l'instant dans Nextcloud Talk : que voulez-vous faire ?",
    "Leave this page" : "Quitter cette page",
    "Join here" : "Rejoignez la conversation",
    "Deck card has been posted to {conversation}" : "Une carte Deck a été postée dans {conversation}",
    "An error occurred while posting deck card to conversation" : "Une erreur est survenue lors de la publication de la carte Deck dans la conversation.",
    "Post to a conversation" : "Envoyer dans une conversation",
    "Post to conversation" : "Envoyer dans la conversation",
    "The recording failed. Please contact your administrator." : "L'enregistrement a échoué. Veuillez contacter votre administrateur.",
    "Location has been posted to {conversation}" : "L'emplacement a été posté dans {conversation}",
    "An error occurred while posting location to conversation" : "Une erreur est survenue lors de la publication de l'emplacement dans la conversation",
    "Share to a conversation" : "Partager dans une conversation",
    "Share to conversation" : "Partager dans la conversation",
    "In conversation" : "Dans une conversation",
    "Search in conversation: {conversation}" : "Rechercher dans la conversation : {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Vos requêtes sont bridées pour le moment par la protection anti force brute",
    "Error while clearing conversation history" : "Erreur à la suppression de l'historique de la conversation",
    "Error occurred while allowing guests" : "Une erreur est survenue lors de l'autorisation des invités",
    "Error occurred while disallowing guests" : "Une erreur est survenue lors de l'interdiction des invités",
    "Error occurred when restricting the conversation to moderator" : "Une erreur est survenue lors de la restriction de la conversation au modérateur",
    "Error occurred when opening the conversation to everyone" : "Une erreur est survenue lors de l'ouverture de la conversation à tout le monde",
    "Conversation password has been saved" : "Le mot de passe de cette conversation a été enregistré",
    "Conversation password has been removed" : "Le mot de passe de cette conversation a été supprimé",
    "Error occurred while saving conversation password" : "Une erreur est survenue lors de l'enregistrement du mot de passe de la conversation",
    "Call recording is starting." : "L'enregistrement de l'appel est lancé.",
    "Call recording stopped while starting." : "L'enregistrement de l'appel s'est arrêté durant son lancement.",
    "Call recording stopped. You will be notified once the recording is available." : "Enregistrement d'appel stoppé. Vous serez averti quand l'enregistrement sera disponible.",
    "Conversation picture set" : "L'image de conversation a été définie",
    "Conversation picture deleted" : "L'image de conversation a été supprimée",
    "Could not delete the conversation picture" : "Impossible de supprimer l'image de cette conversation.",
    "Could not remove the automatic expiration" : "Impossible de retirer l'expiration automatique",
    "Could not post message: {errorMessage}" : "Impossible de publier le message : {errorMessage}",
    "Participant is banned successfully" : "Le participant a été banni avec succès",
    "Error while banning the participant" : "Erreur lors de l'exclusion du participant",
    "An error occurred while fetching the participants" : "Une erreur est survenue pendant la récupération des participants",
    "Could not send invitation to {actorId}" : "Impossible d'envoyer une invitation à {actorId}",
    "Invitations sent" : "Invitations envoyées",
    "Error occurred when sending invitations" : "Une erreur est survenue lors de l'envoi d'invitations",
    "Failed to join the conversation." : "Impossible de rejoindre la conversation.",
    "An error occurred while creating breakout rooms" : "Une erreur est survenue lors de la création des salles de sous-groupes",
    "An error occurred while re-ordering the attendees" : "Une erreur est survenue lors de la réorganisation des participants",
    "An error occurred while deleting breakout rooms" : "Une erreur est survenue lors de la suppression des salles de sous-groupes",
    "An error occurred while starting breakout rooms" : "Une erreur est survenue lors du démarrage des salles de sous-groupes",
    "An error occurred while stopping breakout rooms" : "Une erreur est survenue lors de l'arrêt des salles de sous-groupes",
    "An error occurred while sending a message to the breakout rooms" : "Une erreur est survenue lors de l'envoi d'un message aux salles de sous-groupes",
    "An error occurred while requesting assistance" : "Une erreur est survenue lors de la demande d'assistance",
    "An error occurred while resetting the request for assistance" : "Une erreur est survenue lors de l'annulation de la demande d'assistance",
    "An error occurred while joining breakout room" : "Une erreur est survenue lors de la connexion au salon privé",
    "Failed to rename the thread" : "Impossible de renommer le fil de discussion",
    "Error fetching upcoming events" : "Erreur à la récupération des événements à venir",
    "Error fetching upcoming reminders" : "Erreur à la récupération des rappels à venir",
    "An error occurred while accepting an invitation" : "Une erreur est survenue lors de l'acceptation d'une invitation",
    "An error occurred while rejecting an invitation" : "Une erreur est survenue lors du rejet d'une invitation",
    "{guest} (guest)" : "{guest} (invité)",
    "Poll draft has been saved" : "Le brouillon du sondage a été enregistré",
    "An error occurred while saving the draft" : "Une erreur est survenue lors de l'enregistrement du brouillon",
    "An error occurred while submitting your vote" : "Une erreur est survenue lors de votre participation au sondage",
    "An error occurred while ending the poll" : "Une erreur est survenue au moment de terminer le sondage",
    "An error occurred while deleting the poll draft" : "Une erreur est survenue lors de la suppression du brouillon du sondage",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Le sondage « {name} » a été créé par {user}. Cliquez pour voter",
    "Failed to add reaction" : "Impossible d'ajouter la réaction",
    "Failed to remove reaction" : "Impossible de supprimer la réaction",
    "Error while uploading file \"{fileName}\"" : "Erreur lors du téléversement du fichier \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Espace libre insuffisant pour téléverser le fichier \"{fileName}\"",
    "You are not allowed to share files" : "Vous n'êtes pas autorisé à partager des fichiers",
    "Error while sharing file" : "Erreur lors du partage du fichier",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Le navigateur que vous utilisez n'est pas entièrement pris en charge par Nextcloud Talk. Veuillez utiliser la dernière version de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ou Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["Dans %n heure","Dans %n heures","Dans %n heures"],
    "_%n minute _::_%n minutes_" : ["%n minute","%n minutes","%n minutes"],
    "In {hours} and {minutes}" : "Dans {hours} et {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Dans %n minute","Dans %n minutes","Dans %n minutes"],
    "Later today – {timeLocale}" : "Plus tard aujourd'hui – {timeLocale}",
    "Set time for later today" : "Sélectionner l'horaire pour plus tard aujourd'hui",
    "Tomorrow – {timeLocale}" : "Demain – {timeLocale}",
    "Set time for tomorrow" : "Sélectionner l'horaire pour demain",
    "This weekend – {timeLocale}" : "Ce week-end – {timeLocale}",
    "Set time for this weekend" : "Sélectionner l'horaire pour ce week-end",
    "Next week – {timeLocale}" : "Semaine prochaine – {timeLocale}",
    "Set time for next week" : "Sélectionner l'horaire pour la semaine prochaine",
    "Message link copied to clipboard" : "Le lien vers le message a été copié dans le presse-papier",
    "Conversation link copied to clipboard" : "Lien de la conversation copié dans le presse-papier",
    "The link could not be copied" : "Le lien n'a pas pu être copié",
    "Error while parsing a PROPFIND error" : "Erreur lors de l'analyse d'une erreur PROPFIND",
    "Sending signaling message has failed" : "L'envoi du message de signalement a échoué",
    "Lost connection to signaling server. Trying to reconnect." : "Connexion au serveur perdue. Essayez de vous reconnecter",
    "Lost connection to signaling server." : "Connexion au serveur de signalement perdue.",
    "Connecting is taking longer than expected …" : "La connexion prend plus de temps que prévu…",
    "Failed to connect. Retrying …" : "Échec de la connexion. Nouvel essai…",
    "Failed to connect. The signaling server may be set up incorrectly" : "Échec de la connexion. Le serveur de signalisation est peut-être mal configuré.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Le serveur de signalement configuré doit être mis à jour pour être compatible avec cette version de Talk. Veuillez contacter votre administrateur.",
    "Please restart the app." : "Merci de redémarrer l'application.",
    "Please reload the page." : "Veuillez recharger la page.",
    "Please try to restart the app." : "Merci d'essayer de redémarrer l'application.",
    "Please try to reload the page." : "Merci d'essayer de recharger la page.",
    "Do not disturb" : "Ne pas déranger",
    "Away" : "Absent",
    "Microphone {number}" : "Microphone {number}",
    "Camera {number}" : "Caméra {number}",
    "Speaker {number}" : "Haut-parleur {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Vous semblez parler avec le micro coupé, s'il vous plaît, rétablissez votre son pour que les autres vous entendent",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Impossible d'établir une connexion avec au moins un participant. un serveur TURN est probablement nécessaire. Veuillez demander à votre administrateur d'en installer un, en suivant {linkstart}cette documentation{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "L'opération dure plus longtemps que prévu. Si les autorisations média (audio et vidéo) ont déjà été données, re-démarrez votre navigateur web.",
    "Access to microphone & camera is only possible with HTTPS" : "L'accès au microphone et à la caméra est seulement possible en HTTPS",
    "Please move your setup to HTTPS" : "Veuillez modifier votre installation afin d'utiliser HTTPS",
    "Access to microphone & camera was denied" : "L'accès au microphone et à la caméra a été refusé",
    "WebRTC is not supported in your browser" : "WebRTC n'est pas pris en charge par votre navigateur",
    "Please use a different browser like Firefox or Chrome" : "Veuillez utiliser un autre navigateur comme Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Erreur lors de l'accès au microphone et à la caméra",
    "%s Talk on your mobile devices" : "%s Talk sur vos appareils mobiles",
    "Join conversations at any time, anywhere, on any device." : "Rejoignez des conversations n'importe quand, n'importe où, depuis n'importe quel appareil.",
    "Android app" : "Application Android",
    "iOS app" : "Application iOS",
    "__language_name__" : "Français",
    "Webhook Demo" : "Démo Webhook",
    "Call summary (%s)" : "Résumé de l'appel (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Le robot chargé de résumer l'appel publie un message de synthèse après l'appel, énumérant tous les participants et décrivant les tâches à accomplir.",
    "Tasks" : "Tâches",
    "Notes" : "Notes",
    "Reports" : "Rapports",
    "Decisions" : "Décisions",
    "Agenda" : "Agenda",
    "Call summary" : "Résumé de l'appel",
    "Call summary - {title}" : "Résumé de l'appel - {title}",
    "Talk conversation for event" : "Conversation Talk pour l'événement",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push est installé, cela améliore les performances des clients de synchronisation.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} n'est pas installé, cela peut entraîner des problèmes de performances lors de l'utilisation de clients de synchronisation.",
    "Next meeting" : "Prochaine réunion",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Planifiez une réunion à partir de votre calendrier. Une conversation Talk doit être définie comme emplacement pour apparaître ici.",
    "Join conversations from remote Nextcloud servers" : "Rejoindre les conversations des serveurs Nextcloud distants",
    "Your default media state has been saved" : "L'état par défaut des médias a été sauvegardé",
    "Set reminder for later today" : "Placer un rappel pour plus tard aujourd'hui",
    "Set reminder for tomorrow" : "Placer un rappel pour demain",
    "Set reminder for this weekend" : "Placer un rappel pour ce week-end",
    "Set reminder for next week" : "Placer un rappel pour la semaine prochaine",
    "Generate summary" : "Générer un résumé",
    "Open poll • You voted already" : "Sondage ouvert • Vous avez déjà voté",
    "Open poll • Click to vote" : "Sondage ouvert • Cliquez pour voter",
    "Poll • Ended" : "Sondage • Terminé",
    "Talk recording from {time} ({conversation})" : "Enregistrement de la conversation à partir de {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Résultats du sondage • %n vote","Résultats du sondage • %n votes","Résultats du sondage • %n votes"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Sondage ouvert • %n vote","Sondage ouvert • %n votes","Sondage ouvert • %n votes"],
    "Submit vote" : "Valider le vote",
    "Your privacy setting has been saved" : "Vos paramètres de confidentialité ont été enregistrés",
    "Your personal setting has been saved" : "Vos paramètres personnels ont été sauvegardés",
    "Failed to save sounds setting" : "Impossible d'enregistrer les paramètres audio",
    "Sounds setting saved" : "Paramètres audio enregistrés",
    "Always shown if recording consent is required" : "Toujours visible si le consentement à l'enregistrement est requis",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk a été mis à jour, vous ne pouvez pas démarrer ou rejoindre un appel.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Vous avez déjà ouvert une conversation dans une autre fenêtre ou sur un autre périphérique. Ce n'est pas supporté pour l'instant dans Nextcloud Talk, votre session a été fermée. ",
    "Nextcloud Talk was updated." : "Nextcloud Talk a été mis à jour.",
    "Nextcloud is in maintenance mode." : "Nextcloud est en mode maintenance.",
    "Nextcloud Talk Federation was updated." : "La fédération Nextcloud Talk a été mise à jour.",
    "Enable live translation" : "Activer la traduction en direct",
    "I picked list style" : "J'ai choisi le style liste",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Hé ! Utilisez-vous Talk en mode liste ou avec des bulles de message ?"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
